@@ -20,11 +20,9 @@ inline int tropical_year (int year)
 int moon_phase_leueshkanov (int year, int month, int day)
 {
   int L = tropical_year (year);
-//  int phase = L * 11 - 14 + day + month;
   int phase = L * 11 - 14 + day + month + 3;
 
   return phase % 30;
-
 }
 
 
@@ -161,104 +159,78 @@ void CCalendarWidget::paintCell (QPainter *painter, const QRect &rect, const QDa
 
   if (moon_mode)
      {
-     //int moon_day = moon_phase_trig2 (date.year(), date.month(), date.day());
+      int moon_day = moon_phase_by_algo (moon_phase_algo, date.year(), date.month(), date.day());
 
-     int moon_day = moon_phase_by_algo (moon_phase_algo, date.year(), date.month(), date.day());
+      bool has_image = true;
 
-     bool has_image = true;
+      if (moon_day == 0 || moon_day == 30 || moon_day == 1)
+         has_image = false;
 
-     if (moon_day == 0 || moon_day == 30 || moon_day == 1)
-        has_image = false;
+      //вычисляем ряд и колонку
 
-     //вычисляем ряд и колонку
+     //правильно
+     //int row = moon_day / 8;
 
-    //правильно
-//     int row = moon_day / 8;
-     int cursorOffset = moon_day;
+      int cursorOffset = moon_day;
 
-     int off = 0;
-     int row = 0;
+      int off = 0;
+      int row = 0;
 
-     while (cursorOffset >= (off + 8))
-           {
-            off += 7;
-            row++;
-           }
+      while (cursorOffset >= (off + 8))
+            {
+             off += 7;
+             row++;
+            }
 
-     int col = cursorOffset - off;
+      int col = cursorOffset - off;
 
  //    qDebug() << "moon day: " << moon_day << "| date:" << date.toString("dd") << " | row = " << row << " col = " << col;
 
     //вычисляем, откуда копировать
 
-     int pad = 3;
+      int pad = 3;
 
-     int x = (col - 1) * 73 + (pad * col) - pad;
-     int y = row * 73 + (pad * row);
+      int x = (col - 1) * 73 + (pad * col) - pad;
+      int y = row * 73 + (pad * row);
 
-     QRect r (x, y, 66, 73);
+      QRect r (x, y, 66, 73);
 
-     QImage tile = moon_tiles.copy (r);
+      QImage tile = moon_tiles.copy (r);
 
-     QColor bg_color (Qt::black);
+      QColor bg_color (Qt::black);
 
-     painter->fillRect (rect, bg_color);
-  //   painter->setBrush (QBrush (Qt::black));
+      painter->fillRect (rect, bg_color);
 
 
-     if (has_image)
-        {
-         if (northern_hemisphere)
-            painter->drawImage (rect.x(), rect.y(), tile);
-         else
-             painter->drawImage (rect.x(), rect.y(), tile.mirrored (true, false));
-        }
+      if (has_image)
+         {
+          if (northern_hemisphere)
+             painter->drawImage (rect.x(), rect.y(), tile);
+          else
+              painter->drawImage (rect.x(), rect.y(), tile.mirrored (true, false));
+         }
 
-     painter->setPen (QPen (Qt::yellow));
+      painter->setPen (QPen (Qt::yellow));
 
-     QTextCharFormat tcf = dateTextFormat (date);
-     if (tcf.fontStrikeOut())
-        {
-         painter->setPen (QPen (Qt::magenta));
-//         painter->setFont (font_past);
-        }
-     else
-     if (tcf.fontUnderline())
-        {
-     //    painter->setFont (font_future);
-         painter->setPen (QPen (Qt::red));
+      QTextCharFormat tcf = dateTextFormat (date);
+      if (tcf.fontStrikeOut())
+          painter->setPen (QPen (Qt::magenta));
+      else
+      if (tcf.fontUnderline())
+          painter->setPen (QPen (Qt::red));
 
-//         qDebug() << "font_future / " << date.toString();
-        }
-  //   else
-    //     painter->setFont (font_normal);
+      painter->drawText (QPoint (rect.x() + 5, rect.y() + fsize.height()), date.toString("dd") + " / " + QString::number (moon_day));
 
-     painter->drawText (QPoint (rect.x() + 5, rect.y() + fsize.height()), date.toString("dd") + " / " + QString::number (moon_day));
-
-     if (selectedDate() == date)
-        {
-         QPen dpen (Qt::yellow);
-         dpen.setWidth (5);
-         painter->setPen (dpen);
-         painter->drawRect (rect);
-        }
-/*
-     if (tcf.fontUnderline())
-        {
-         QPolygon triangle (3);
-         triangle [0] = QPoint (rect.x() + get_value (rect.width(), 70), rect.y());
-         triangle [1] = QPoint (rect.x() + rect.width(), rect.y());
-         triangle [2] = QPoint (rect.x() + rect.width(), rect.y() + get_value (rect.height(), 50));
-         painter->setBrush (QBrush (Qt::magenta));
-
-         painter->drawPolygon (triangle);
-        }
-*/
+      if (selectedDate() == date)
+         {
+          QPen dpen (Qt::yellow);
+          dpen.setWidth (5);
+          painter->setPen (dpen);
+          painter->drawRect (rect);
+         }
     }
  else
-     {
-      QCalendarWidget::paintCell (painter, rect, date);
-     }
+     QCalendarWidget::paintCell (painter, rect, date);
 }
 
 
