@@ -1,7 +1,9 @@
 #ifndef CALENDAR_H
 #define CALENDAR_H
 
-#include <QtGui>
+
+#include <QCalendarWidget>
+
 
 class CCalendarWidget: public QCalendarWidget
 {
@@ -33,11 +35,7 @@ enum
 };
 
 
-
-
 int moon_phase_by_algo (int v, int year, int month, int day);
-
-
 int moon_phase_trig2 (int year, int month, int day);
 int moon_phase_simple (int year, int month, int day);
 int moon_phase_conway (int year, int month, int day);
@@ -45,5 +43,4 @@ int moon_phase_trig1 (int year, int month, int day);
 int moon_phase_leueshkanov (int year, int month, int day);
 
 
-
 #endif // CALENDAR_H
