@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2007-2012 by Peter Semiletov                            *
- *   peter.semiletov@gmail.com                                             *
+ *   2007-2013 by Peter Semiletov                                          *
+ *   tea@list.ru                                                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -44,13 +44,20 @@ code from qwriter:
 #include "utils.h"
 #include "gui_utils.h"
 
-//#include <QtGui>
-
-//#include <QPlainTextEdit>
-
-#include <QDomDocument>
+#include <QSettings>
 #include <QLabel>
 #include <QPainter>
+#include <QDebug>
+#include <QUrl>
+#include <QDir>
+#include <QXmlStreamReader>
+#include <QMimeData>
+
+#if QT_VERSION >= 0x050000
+
+#include <QRegularExpression>
+
+#endif
 
 
 QSettings *settings;
@@ -121,12 +128,15 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
      }
 
   charset = tio->charset;
+  eol = tio->eol;
+
   textEdit->setPlainText (tio->data);
 
   file_name = fileName;
 
   set_tab_caption (QFileInfo (file_name).fileName());
   set_hl();
+  
   set_markup_mode();
   textEdit->document()->setModified (false);
 
@@ -140,7 +150,7 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
          if (lt.size() > 0 && lt[0] == file_name) 
             i.remove();
         }
-
+       
   return true;
 }
 
@@ -156,15 +166,8 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
 
   tio->data = textEdit->toPlainText();
   
-  if (eol_changed && (new_eol != def_eol))
-      tio->data.replace ("\n", new_eol);
-   
-#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
-
-  if (! eol_changed)
-      tio->data.replace ("\n", def_eol);
-
-#endif
+   if (eol != "\n")
+      tio->data.replace ("\n", eol);
 
   if (! tio->save (fileName))
      {
@@ -203,19 +206,37 @@ CDocument::CDocument (QObject *parent): QObject (parent)
   charset = "UTF-8";
   text_to_search = "";
   position = 0;
-  eol_changed = false;
   
-#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
-  def_eol = "\r\n";
+  eol = "\r\n";
 
-#else
+//  qDebug() << "defined(Q_OS_WIN) || defined(Q_OS_OS2)";
+
+#elif defined(Q_OS_LINUX)
+
+  eol = "\n";
+
+  //qDebug() << "Q_OS_LINUX";
+
+
+#elif defined(Q_OS_MAC)
+
+  eol = "\r";
+
+  //qDebug() << "Q_OS_MAC";
 
-  def_eol = "\n";
 
 #endif
-  
-  new_eol = def_eol;
+
+  //qDebug() << "CDocument()";
+
+  if (eol == "\n")
+    qDebug() << "LF";
+  if (eol == "\r\n")
+    qDebug() << "CRLF";
+  if (eol == "\r")
+    qDebug() << "CR";
 }
 
 
@@ -256,9 +277,9 @@ void CDocument::create_new()
 
   textEdit->doc = this;
 
-  textEdit->currentLineColor = hash_get_val (holder->palette, 
+  textEdit->currentLineColor =  QColor (hash_get_val (holder->palette, 
                                              "cur_line_color", 
-                                             "#EEF6FF");
+                                             "#EEF6FF")).darker (settings->value ("darker_val", 100).toInt()).name();
 
   highlighter = NULL;
 
@@ -379,13 +400,7 @@ void document_holder::close_by_idx (int i)
 
 void document_holder::close_current()
 {
-  int i = tab_widget->currentIndex();
-  if (i < 0)
-     return;
-
-  CDocument *d = list[i];
-  list.removeAt (i);
-  delete d;
+  close_by_idx (tab_widget->currentIndex());
 }
 
 
@@ -426,37 +441,100 @@ QString CDocument::get_filename_at_cursor()
 
   QString x;
 
-  int pos = textEdit->textCursor().position();
+  if (markup_mode == "LaTeX")
+     {
+      int pos = textEdit->textCursor().position();
 
-  int end = s.indexOf ("\"", pos);
-  if (end == -1)
-     return x;
+      int end = s.indexOf ("}", pos);
+      if (end == -1)
+         return x;
 
-  int start = s.lastIndexOf ("\"", pos);
-  if (start == -1)
-     return x;
+     int start = s.lastIndexOf ("{", pos);
+     if (start == -1)
+        return x;
 
-  x = s.mid (start + 1, end - (start + 1));
+     x = s.mid (start + 1, end - (start + 1));
+     
+     QFileInfo inf (file_name);
+     QDir cur_dir (inf.absolutePath());
 
-  if (x.startsWith("#"))
-     return x;
+         
+     QString result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
+     if (file_exists (result))
+         return result;
 
-  QFileInfo inf (file_name);
-  QDir cur_dir (inf.absolutePath());
 
-  return cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
+     
+     int i = x.lastIndexOf ("/");
+     if (i < 0)
+        i = x.lastIndexOf ("\\");
+     
+     if (i < 0)
+        return QString();
+
+     x = x.mid (i + 1);   
+
+     qDebug() << "x = " << x;
+
+     
+     result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
+     qDebug() << "in cur dir: " << result;
+     return result;
+    }
+  else
+ //   if (markup_mode == "HTML")
+   //fallback to HTML markup 
+     {
+      int pos = textEdit->textCursor().position();
+
+      int end = s.indexOf ("\"", pos);
+      if (end == -1)
+         return x;
+
+      int start = s.lastIndexOf ("\"", pos);
+      if (start == -1)
+         return x;
+
+      x = s.mid (start + 1, end - (start + 1));
+
+      if (x.startsWith("#"))
+         return x;
+
+      QFileInfo inf (file_name);
+      QDir cur_dir (inf.absolutePath());
+
+      return cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
+     }
+
+ 
+  
 }
 
 
-CSyntaxHighlighter::CSyntaxHighlighter (QTextDocument *parent, CDocument *doc):
-                                        QSyntaxHighlighter (parent)
+CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDocument *doc, const QString &fname):
+                                        CSyntaxHighlighter (parent)
 {
   document = doc;
   casecare = true;
   wrap = true;
+  load_from_xml (fname);
 }
 
 
+#if QT_VERSION >= 0x050000
+
+CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTextDocument *parent, CDocument *doc, const QString &fname):
+                                        CSyntaxHighlighter (parent)
+{
+  document = doc;
+  casecare = true;
+  wrap = true;
+  load_from_xml (fname);
+}
+
+#endif
+
+
 void CDocument::set_hl (bool mode_auto, const QString &theext)
 {
   QString ext;
@@ -476,6 +554,9 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
      return;
 
   QString fname = holder->hls.value (ext);
+  
+  qDebug() << "hl fname is " << fname;
+  
 
   if (fname.isNull() || fname.isEmpty())
      return;
@@ -483,8 +564,22 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
   if (highlighter)
      delete highlighter;
   
-  highlighter = new CSyntaxHighlighter (textEdit->document(), this);
-  highlighter->load_from_xml (fname);
+#if QT_VERSION >= 0x050000
+  
+  if (settings->value ("qregexpsyntaxhl", 0).toBool())
+     highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
+  else
+     highlighter = new CSyntaxHighlighterQRegularExpression (textEdit->document(), this, fname);
+  
+  
+#else
+  
+  highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
+  
+  
+#endif  
+  
+  //highlighter->load_from_xml (fname);
       
   if (textEdit->use_hl_wrap)
      {
@@ -494,7 +589,7 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
           textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
      }
   
-//  qDebug() << "hl file is: " << fname;
+ // qDebug() << "hl file is: " << fname;
 }
 
 
@@ -509,6 +604,9 @@ void CDocument::goto_pos (int pos)
 void document_holder::apply_settings_single (CDocument *d)
 {
   QFont f;
+
+  int darker_val = settings->value ("darker_val", 100).toInt();
+
   
   f.fromString (settings->value ("editor_font_name", "Monospace").toString());
   f.setPointSize (settings->value ("editor_font_size", "12").toInt());
@@ -519,6 +617,11 @@ void document_holder::apply_settings_single (CDocument *d)
   
   d->textEdit->use_hl_wrap = settings->value ("use_hl_wrap", true).toBool();
   
+  if (settings->value ("right_to_left", false).toBool())
+     d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignRight));
+  else
+     d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignLeft));
+    
   if (settings->value ("word_wrap", "2").toInt() == 2)
      d->textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
   else
@@ -534,32 +637,40 @@ void document_holder::apply_settings_single (CDocument *d)
   d->textEdit->set_show_linenums (settings->value ("show_linenums", false).toBool());
   d->textEdit->set_show_margin (settings->value ("show_margin", false).toBool());
   d->textEdit->set_margin_pos (settings->value ("margin_pos", 72).toInt());
-
+  
+  
   d->textEdit->highlightCurrentLine = settings->value ("additional_hl", false).toBool();
   d->textEdit->hl_brackets = settings->value ("hl_brackets", false).toBool();
 
-  d->textEdit->currentLineColor = QColor (hash_get_val (palette, "cur_line_color", "#EEF6FF"));
-  d->textEdit->brackets_color = QColor (hash_get_val (palette, "brackets", "yellow"));
+  d->textEdit->currentLineColor = QColor (hash_get_val (palette, "cur_line_color", "#EEF6FF")).darker (darker_val);
+  d->textEdit->brackets_color = QColor (hash_get_val (palette, "brackets", "yellow")).darker (darker_val);
   
   d->cursor_xy_visible = settings->value ("cursor_xy_visible", "2").toBool();
   d->textEdit->auto_indent = settings->value ("auto_indent", false).toBool();
 
   QString text_color = hash_get_val (palette, "text", "black");
-  d->textEdit->text_color = QColor (text_color);
+  QString t_text_color = QColor (text_color).darker(darker_val).name(); 
+    
+  d->textEdit->text_color = QColor (t_text_color);
 
   QString back_color = hash_get_val (palette, "background", "white");
   QString sel_back_color = hash_get_val (palette, "sel-background", "black");
   QString sel_text_color = hash_get_val (palette, "sel-text", "white");
 
-  d->textEdit->margin_color = QColor (hash_get_val (palette, "margin_color", text_color));
-  d->textEdit->linenums_bg = QColor (hash_get_val (palette, "linenums_bg", back_color));
-
+  d->textEdit->margin_color = QColor (hash_get_val (palette, "margin_color", text_color)).darker(darker_val);
+  d->textEdit->linenums_bg = QColor (hash_get_val (palette, "linenums_bg", back_color)).darker(darker_val);
+  
+  QString t_back_color = QColor (back_color).darker(darker_val).name(); 
+  QString t_sel_text_color = QColor (sel_text_color).darker(darker_val).name(); 
+  QString t_sel_back_color = QColor (sel_back_color).darker(darker_val).name(); 
+    
+  
   QString sheet = QString ("QPlainTextEdit { color: %1 ; background-color: %2 ; selection-color: %3; selection-background-color: %4;}").arg (
-                           text_color).arg (
-                           back_color).arg (
-                           sel_text_color).arg (
-                           sel_back_color);
-
+                           t_text_color).arg (
+                           t_back_color).arg (
+                           t_sel_text_color).arg (
+                           t_sel_back_color);
+                           
   d->textEdit->setStyleSheet (sheet);
   d->textEdit->repaint();
   d->set_hl();
@@ -601,7 +712,7 @@ void document_holder::open_recent()
 {
   QAction *act = qobject_cast<QAction *>(sender());
 
-  int i = recent_files.indexOf (act->text ());
+  int i = recent_files.indexOf (act->text());
   if (i == -1)
      return;
 
@@ -655,6 +766,12 @@ void CDocument::set_markup_mode()
   else
   if (e == "lout")
     markup_mode = "Lout";
+  else
+  if (e == "dokuwiki")
+    markup_mode = "DokuWiki";
+  else
+  if (e == "mediawiki")
+    markup_mode = "MediaWiki";
 }
 
 
@@ -670,7 +787,7 @@ void CTEAEdit::cb_cursorPositionChanged()
 }
 
 
-void CTEAEdit::setCurrentLineColor (const QColor &newColor )
+void CTEAEdit::setCurrentLineColor (const QColor &newColor)
 {
   currentLineColor = newColor;
   emit repaint();
@@ -773,6 +890,9 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
   use_hl_wrap = true;
   tab_sp_width = 8;
   spaces_instead_of_tabs = true;
+  
+  //document()->setDefaultTextOption(QTextOption(Qt::AlignRight));
+  
   connect (this, SIGNAL(cursorPositionChanged()), this, SLOT(cb_cursorPositionChanged()));
 }
 
@@ -818,77 +938,10 @@ QStringList CDocument::get_words()
 }
 
 
-void CSyntaxHighlighter::highlightBlock (const QString &text)
-{
-  foreach (HighlightingRule rule, highlightingRules)
-          {
-           QRegExp expression (rule.pattern);
-
-           int index;
-
-           if (! casecare)
-              index = text.toLower().indexOf (expression);
-           else
-               index = text.indexOf (expression);
-
-           while (index >= 0)
-                 {
-                  int length = expression.matchedLength();
-                  setFormat (index, length, rule.format);
-
-                  if (! casecare)
-                      index = text.toLower().indexOf (expression, index + length);
-                  else
-                      index = text.indexOf (expression, index + length);
-                 }
-           }
-
-  setCurrentBlockState (0);
-
-  int startIndex = 0;
-
-  if (commentStartExpression.isEmpty() || commentEndExpression.isEmpty())
-     return;
-
-  if (previousBlockState() != 1)
-     {
-      if (! casecare)
-         startIndex = text.toLower().indexOf (commentStartExpression);
-      else
-          startIndex = text.indexOf (commentStartExpression);
-     }
-
-  while (startIndex >= 0)
-        {
-         int endIndex;
-         if (! casecare)
-            endIndex = text.toLower().indexOf (commentEndExpression, startIndex);
-         else
-             endIndex = text.indexOf (commentEndExpression, startIndex);
-
-         int commentLength;
-         if (endIndex == -1)
-            {
-             setCurrentBlockState (1);
-             commentLength = text.length() - startIndex;
-            }
-         else
-             commentLength = endIndex - startIndex + commentEndExpression.matchedLength();
-
-         setFormat (startIndex, commentLength, multiLineCommentFormat);
-
-         if (! casecare)
-            startIndex = text.toLower().indexOf (commentStartExpression, startIndex + commentLength);
-         else
-              startIndex = text.indexOf (commentStartExpression, startIndex + commentLength);
-        }
-}
-
-
-QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &color)
+QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &color, int darker_val)
 {
   QTextCharFormat tformat;
-  tformat.setForeground (QBrush (QColor (color)));
+  tformat.setForeground (QBrush (QColor (color).darker (darker_val)));
 
   if (fontstyle.isNull() || fontstyle.isEmpty())
      return tformat; 
@@ -904,106 +957,365 @@ QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &col
 
   if (fontstyle.contains ("strikeout"))
       tformat.setFontStrikeOut (true);
-
+  
   return tformat;
 }
 
 
-void CSyntaxHighlighter::load_from_xml (const QString &fname)
+#if QT_VERSION >= 0x050000
+
+
+void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 {
-  exts = "default";   
-  langs = "default";   
+  exts = "default";
+  langs = "default";
   
-  QDomDocument doc ("mydocument");
-
-  if (! doc.setContent (qstring_load (fname)))
-      return;
-
-  QDomElement docElem = doc.documentElement();
-
-  exts = docElem.attribute ("exts", "default");   
-  langs = docElem.attribute ("langs", "default");   
-
-  QDomNode n = docElem.firstChild();
+  int darker_val = settings->value ("darker_val", 100).toInt();
   
-  while (! n.isNull())
+  pattern_opts = 0;
+  
+  QString temp = qstring_load (fname);
+  QXmlStreamReader xml (temp);
+
+  
+   while (! xml.atEnd())
         {
-         QDomElement e = n.toElement();
+         xml.readNext();
 
-         if (! e.isNull())
+         QString tag_name = xml.name().toString().toLower();
+
+
+         if (xml.isStartElement())
+            if (tag_name == "document")
+                {
+                 exts = xml.attributes().value ("exts").toString();
+                 langs = xml.attributes().value ("langs").toString();
+                }
+
+         if (xml.isStartElement())
             {
-             if (e.attribute ("name") == "options")
-                {
-                 QString s_casecare = e.attribute ("casecare");
-                 if (! s_casecare.isNull() || ! s_casecare.isEmpty())
-                    if (s_casecare == "0" || s_casecare == "false")
-                       casecare = false;
-                
-                 QString s_wrap = e.attribute ("wrap");
-                 if (! s_wrap.isNull() || ! s_wrap.isEmpty())
-                    if (s_wrap == "0" || s_wrap == "false")
-                       wrap = false;
-                }
 
-
-             if (e.attribute ("type") == "keywords")
+             if (tag_name == "item")
                 {
-                 //qDebug () << e.attribute ("name");
-                 QString color = hash_get_val (document->holder->palette, e.attribute ("color"), "darkBlue");
-                 QTextCharFormat fmt = tformat_from_style (e.attribute ("fontstyle"), color);
-   
-                 QStringList keywordPatterns = e.text().trimmed().split(";");
-                 HighlightingRule rule;
+                 QString attr_type = xml.attributes().value ("type").toString();
+                 QString attr_name = xml.attributes().value ("name").toString();
 
-                 for (int i = 0; i < keywordPatterns.size(); i++)  
-                     {
-                      if (! keywordPatterns.at(i).isNull())
-                         {
-                          rule.pattern = QRegExp (keywordPatterns.at(i).trimmed());
-                          rule.format = fmt;
-                          highlightingRules.append (rule);                 
-                         }
-                     }   
-                 }
-             else
-             if (e.attribute("type") == "item")
-                {
-                 QString color = hash_get_val (document->holder->palette, e.attribute("color"), "darkBlue");
-                 QTextCharFormat fmt = tformat_from_style (e.attribute ("fontstyle"), color);
+                 if (attr_name == "options")
+                    {
+                     QString s_wrap = xml.attributes().value ("wrap").toString();
+                     if (! s_wrap.isNull() || ! s_wrap.isEmpty())
+                        if (s_wrap == "0" || s_wrap == "false")
+                           wrap = false;
+                        
+                     QString s_casecare = xml.attributes().value ("casecare").toString();
+                     if (! s_casecare.isNull() || ! s_casecare.isEmpty())
+                        if (s_casecare == "0" || s_casecare == "false")
+                           casecare = false;
+                        
+                     if (! casecare) 
+                       pattern_opts = pattern_opts | QRegularExpression::CaseInsensitiveOption;                    
+                     
+                     }
 
-                 HighlightingRule rule;
-                 rule.pattern = QRegExp (e.text().trimmed());
-                 rule.format = fmt;
-                 highlightingRules.append(rule);
-                }
-             else
-             if (e.attribute("type") == "mcomment-start")
-                {
-                 QString color = hash_get_val (document->holder->palette, e.attribute("color"), "gray");
-                 QTextCharFormat fmt = tformat_from_style (e.attribute ("fontstyle"), color);
+                 if (attr_type == "keywords")
+                    {
+                     QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                     QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
-                 multiLineCommentFormat = fmt;
-                 commentStartExpression = QRegExp (e.text().trimmed());
-                }
-             else
-             if (e.attribute("type") == "mcomment-end")
-                commentEndExpression = QRegExp (e.text().trimmed());
-             else
-             if (e.attribute("type") == "comment")
-                {
-                 if (e.attribute ("name") == "cm_mult")
-                    cm_mult = e.text().trimmed();
+                     QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
+
+                     HighlightingRule rule;
+
+                     for (int i = 0; i < keywordPatterns.size(); i++)
+                          if (! keywordPatterns.at(i).isNull())
+                             {
+                              rule.pattern = QRegularExpression (keywordPatterns.at(i).trimmed(), pattern_opts);
+                              rule.format = fmt;
+                              highlightingRules.append (rule);
+                              
+                              if (! rule.pattern.isValid())
+                                  qDebug() << "! valid " << rule.pattern.pattern();
+                              
+                             }
+                     } //keywords
                  else
-                 if (e.attribute ("name") == "cm_single")
-                    cm_single = e.text().trimmed();
-                }
-            }
+                    if (attr_type == "item")
+                       {
+                        QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                        QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
-         n = n.nextSibling();
+                        HighlightingRule rule;
+                        rule.pattern = QRegularExpression (xml.readElementText().trimmed(), pattern_opts);
+                        rule.format = fmt;
+                        highlightingRules.append(rule);
+                        
+                        if (! rule.pattern.isValid())
+                           qDebug() << "! valid " << rule.pattern.pattern();
+
+                       }
+                    else
+                        if (attr_type == "mcomment-start")
+                           {
+                            QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "gray");
+                            QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("color").toString(), color, darker_val);
+
+                            multiLineCommentFormat = fmt;
+                            commentStartExpression = QRegularExpression (xml.readElementText().trimmed(), pattern_opts);
+                           }
+                    else
+                        if (attr_type == "mcomment-end")
+                           {
+                            commentEndExpression = QRegularExpression (xml.readElementText().trimmed(), pattern_opts);
+                           }
+                    else
+                        if (attr_type == "comment")
+                           {
+                            if (xml.attributes().value ("name").toString() == "cm_mult")
+                               cm_mult = xml.readElementText().trimmed();
+                            else
+                            if (xml.attributes().value ("name").toString() == "cm_single")
+                               cm_single = xml.readElementText().trimmed();
+
+                          }
+
+                     }//item
+
+       }//is start
+
+  if (xml.hasError())
+     qDebug() << "xml parse error";
+
+  } //cycle
+  
+}
+
+
+void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
+{
+  foreach (HighlightingRule rule, highlightingRules)
+          {
+           QRegularExpressionMatch m = rule.pattern.match (text);
+           
+           int index = m.capturedStart();
+  
+           while (index >= 0)
+                 {
+                  int length = m.capturedLength();
+                   
+                  setFormat (index, length, rule.format);
+  
+                  m = rule.pattern.match (text, index + length);
+
+                  index = m.capturedStart();
+                 }
+          }
+
+  setCurrentBlockState (0);
+
+  int startIndex = 0;
+
+  if (! commentStartExpression.isValid() || ! commentEndExpression.isValid())
+     return;
+
+  QRegularExpressionMatch m_start = commentStartExpression.match (text);
+  
+  if (previousBlockState() != 1)
+      startIndex = m_start.capturedStart();
+
+  while (startIndex >= 0)
+        {
+         QRegularExpressionMatch m_end = commentEndExpression.match (text, startIndex);
+         
+         int endIndex = m_end.capturedStart();
+         
+         int commentLength;
+
+         if (endIndex == -1)
+            {
+             setCurrentBlockState (1);
+             commentLength = text.length() - startIndex;
+            }
+         else
+             commentLength = endIndex - startIndex + m_end.capturedLength();
+
+         setFormat (startIndex, commentLength, multiLineCommentFormat);
+
+         m_start = commentStartExpression.match (text, startIndex + commentLength);
+         startIndex = m_start.capturedStart(); 
+        }
+
+//   qDebug() << "2";
+}
+
+#endif
+
+void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
+{
+  //qDebug() << "CSyntaxHighlighter::load_from_xml - start";
+
+  int darker_val = settings->value ("darker_val", 100).toInt();
+ 
+  exts = "default";
+  langs = "default";
+
+  cs = Qt::CaseSensitive;
+  
+  QString temp = qstring_load (fname);
+  QXmlStreamReader xml (temp);
+
+   while (! xml.atEnd())
+        {
+         xml.readNext();
+
+         QString tag_name = xml.name().toString().toLower();
+
+
+         if (xml.isStartElement())
+            if (tag_name == "document")
+                {
+                 exts = xml.attributes().value ("exts").toString();
+                 langs = xml.attributes().value ("langs").toString();
+                }
+
+         if (xml.isStartElement())
+            {
+
+             if (tag_name == "item")
+                {
+                 QString attr_type = xml.attributes().value ("type").toString();
+                 QString attr_name = xml.attributes().value ("name").toString();
+
+                 if (attr_name == "options")
+                    {
+                     QString s_wrap = xml.attributes().value ("wrap").toString();
+                     if (! s_wrap.isNull() || ! s_wrap.isEmpty())
+                        if (s_wrap == "0" || s_wrap == "false")
+                           wrap = false;
+                        
+
+                     QString s_casecare = xml.attributes().value ("casecare").toString();
+                     if (! s_casecare.isNull() || ! s_casecare.isEmpty())
+                        if (s_casecare == "0" || s_casecare == "false")
+                           casecare = false;
+                        
+                     if (! casecare) 
+                        cs = Qt::CaseInsensitive;
+                     }
+
+                 if (attr_type == "keywords")
+                    {
+                     QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                     QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
+
+                     QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
+
+                     HighlightingRule rule;
+
+                     for (int i = 0; i < keywordPatterns.size(); i++)
+                          if (! keywordPatterns.at(i).isNull())
+                             {
+                              rule.pattern = QRegExp (keywordPatterns.at(i).trimmed(), cs, QRegExp::RegExp);
+                              rule.format = fmt;
+                              highlightingRules.append (rule);
+                             }
+                     } //keywords
+                 else
+                    if (attr_type == "item")
+                       {
+                        QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                        QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
+
+                        HighlightingRule rule;
+                        rule.pattern = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
+                        rule.format = fmt;
+                        highlightingRules.append(rule);
+                       }
+                    else
+                        if (attr_type == "mcomment-start")
+                           {
+                            QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "gray");
+                            QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("color").toString(), color, darker_val);
+
+                            multiLineCommentFormat = fmt;
+                            commentStartExpression = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
+                           }
+                    else
+                        if (attr_type == "mcomment-end")
+                           {
+                            commentEndExpression = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
+                           }
+                    else
+                        if (attr_type == "comment")
+                           {
+                            if (xml.attributes().value ("name").toString() == "cm_mult")
+                               cm_mult = xml.readElementText().trimmed();
+                            else
+                            if (xml.attributes().value ("name").toString() == "cm_single")
+                               cm_single = xml.readElementText().trimmed();
+
+                          }
+
+                     }//item
+
+       }//is start
+
+  if (xml.hasError())
+     qDebug() << "xml parse error";
+
+  } //cycle
+  
+}
+
+
+void CSyntaxHighlighterQRegExp::highlightBlock (const QString &text)
+{
+ 
+  foreach (HighlightingRule rule, highlightingRules)
+          {
+           int index;
+
+           index = text.indexOf (rule.pattern);
+
+           while (index >= 0)
+                 {
+                  int length = rule.pattern.matchedLength();
+                  setFormat (index, length, rule.format);
+
+                  index = text.indexOf (rule.pattern, index + length);
+                 }
+           }
+
+  setCurrentBlockState (0);
+
+  int startIndex = 0;
+
+  if (commentStartExpression.isEmpty() || commentEndExpression.isEmpty())
+     return;
+
+  if (previousBlockState() != 1)
+     startIndex = text.indexOf (commentStartExpression);
+
+  while (startIndex >= 0)
+        {
+         int endIndex = text.indexOf (commentEndExpression, startIndex);
+
+         int commentLength;
+         if (endIndex == -1)
+            {
+             setCurrentBlockState (1);
+             commentLength = text.length() - startIndex;
+            }
+         else
+             commentLength = endIndex - startIndex + commentEndExpression.matchedLength();
+
+         setFormat (startIndex, commentLength, multiLineCommentFormat);
+
+         startIndex = text.indexOf (commentStartExpression, startIndex + commentLength);
         }
 }
 
 
+
 void document_holder::save_to_session (const QString &fileName)
 {
   if (list.size() < 0)
@@ -1054,6 +1366,7 @@ QString CDocument::get_selected_text() const
   return textEdit->textCursor().selectedText();
 }
 
+
 void CDocument::set_selected_text (const QString &value)
 {
   textEdit->textCursor().insertText (value);
@@ -1183,7 +1496,7 @@ void CTEAEdit::keyPressEvent (QKeyEvent *event)
       event->accept();
       return;
      }
-   
+  else
   if (event->key() == Qt::Key_Backtab)
      {
       un_indent();
@@ -1293,7 +1606,7 @@ void CTEAEdit::braceHighlight()
   QTextCursor cursor = textCursor();
   QTextCursor beforeCursor = cursor;
 
-  cursor.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor);
+  cursor.movePosition (QTextCursor::NextCharacter, QTextCursor::KeepAnchor);
   QString brace = cursor.selectedText();
 
   beforeCursor.movePosition(QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
@@ -1427,13 +1740,9 @@ bool CTEAEdit::canInsertFromMimeData (const QMimeData *source)
 
 void CTEAEdit::insertFromMimeData (const QMimeData *source)
 {
-  qDebug()<< "CTEAEdit::insertFromMimeData ";
-
   QString fName;
   QFileInfo info;
 
- // qDebug() << source->text();
-
   bool b_ins_plain_text = ! source->hasUrls();
   if (source->hasUrls() && source->urls().at(0).scheme() != "file")
       b_ins_plain_text = true;
@@ -1481,7 +1790,6 @@ QStringList text_get_bookmarks (const QString &s, const QString &sstart, const Q
 }
 
 
-
 void CDocument::update_labels()
 {
   labels.clear();
@@ -1489,3 +1797,85 @@ void CDocument::update_labels()
                                         settings->value ("label_start", "[?").toString(),
                                         settings->value ("label_end", "?]").toString());
 }
+
+
+
+/*
+ * 
+ 
+ // new INDEX-IN VARIANT
+
+void CSyntaxHighlighter::highlightBlock (const QString &text)
+{
+ qDebug() << "1";
+ 
+  foreach (HighlightingRule rule, highlightingRules)
+          {
+           QRegExp expression (rule.pattern);
+
+           int index;
+
+           if (! casecare)
+              index = expression.indexIn (text.toLower());
+           else
+               index = expression.indexIn (text);
+
+           while (index >= 0)
+                 {
+                  int length = expression.matchedLength();
+                  setFormat (index, length, rule.format);
+
+                  if (! casecare)
+                      index = expression.indexIn (text.toLower(), index + length);
+                  else
+                      index = expression.indexIn (text, index + length);
+                 }
+           }
+
+  setCurrentBlockState (0);
+
+  int startIndex = 0;
+
+  if (commentStartExpression.isEmpty() || commentEndExpression.isEmpty())
+     return;
+
+  if (previousBlockState() != 1)
+     {
+      if (! casecare)
+         startIndex = commentStartExpression.indexIn (text.toLower());
+      else
+         startIndex = commentStartExpression.indexIn (text);
+     }
+
+  while (startIndex >= 0)
+        {
+         int endIndex;
+         if (! casecare)
+            endIndex = commentEndExpression.indexIn (text.toLower(), startIndex);
+         else
+            endIndex = commentEndExpression.indexIn (text, startIndex);
+
+         int commentLength;
+         if (endIndex == -1)
+            {
+             setCurrentBlockState (1);
+             commentLength = text.length() - startIndex;
+            }
+         else
+             commentLength = endIndex - startIndex + commentEndExpression.matchedLength();
+
+         setFormat (startIndex, commentLength, multiLineCommentFormat);
+
+         if (! casecare)
+            startIndex = commentStartExpression.indexIn (text.toLower(), startIndex + commentLength);
+         else
+            startIndex = commentStartExpression.indexIn (text, startIndex + commentLength);
+        }
+        
+      
+}
+
+ 
+ 
+ * 
+ */
\ No newline at end of file
