@@ -51,11 +51,13 @@ code from qwriter:
 #include <QMainWindow>
 #include <QTabWidget>
 #include <QPlainTextEdit>
-//#include <QList>
-//#include <QString>
 #include <QSyntaxHighlighter>
 
+#if QT_VERSION >= 0x050000
 
+#include <QRegularExpression>
+
+#endif
 
 
 class LineNumberArea;
@@ -63,7 +65,6 @@ class document_holder;
 class CDocument;
 
 
-
 class CTEAEdit: public QPlainTextEdit
 {
   Q_OBJECT
@@ -102,7 +103,6 @@ public:
 
 
   CTEAEdit (QWidget *parent = 0);
-  //~CTEAEdit();
 
   void setCurrentLineColor (const QColor &newColor);
   void set_brackets_color (const QColor &newColor);
@@ -140,6 +140,28 @@ private slots:
 
 
 class CSyntaxHighlighter: public QSyntaxHighlighter
+{
+public:
+ 
+  CSyntaxHighlighter (QTextDocument *parent): QSyntaxHighlighter (parent) {};
+ 
+  CDocument *document;
+  bool casecare;
+  bool wrap;
+  
+  QString exts;
+  QString langs;
+    
+  QString cm_mult;
+  QString cm_single;
+ 
+  QTextCharFormat singleLineCommentFormat;
+  QTextCharFormat multiLineCommentFormat;
+};
+
+
+
+class CSyntaxHighlighterQRegExp: public CSyntaxHighlighter
 {
   Q_OBJECT
 
@@ -155,7 +177,43 @@ public:
          QTextCharFormat format;
         };
 
+  QRegExp commentStartExpression;
+  QRegExp commentEndExpression;      
 
+  Qt::CaseSensitivity cs;  
+    
+  CSyntaxHighlighterQRegExp (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
+
+  QVector <HighlightingRule> highlightingRules;
+ 
+   void load_from_xml (const QString &fname);
+};
+
+
+#if QT_VERSION >= 0x050000
+
+class CSyntaxHighlighterQRegularExpression: public CSyntaxHighlighter
+{
+  Q_OBJECT
+
+protected:
+
+  void highlightBlock (const QString &text);
+
+public:
+ 
+  struct HighlightingRule
+        {
+         QRegularExpression pattern;
+         QTextCharFormat format;
+        };
+        
+  QRegularExpression commentStartExpression;
+  QRegularExpression commentEndExpression;
+
+  QRegularExpression::PatternOptions pattern_opts;
+
+  
   CDocument *document;
   bool casecare;
   bool wrap;
@@ -166,19 +224,18 @@ public:
   QString cm_mult;
   QString cm_single;
     
-  CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0);
+  CSyntaxHighlighterQRegularExpression (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
 
   QVector <HighlightingRule> highlightingRules;
 
   QTextCharFormat singleLineCommentFormat;
   QTextCharFormat multiLineCommentFormat;
 
-  QRegExp commentStartExpression;
-  QRegExp commentEndExpression;
-
   void load_from_xml (const QString &fname);
 };
 
+#endif
+
 
 class CDocument: public QObject
 {
@@ -187,15 +244,17 @@ class CDocument: public QObject
 public:
 
   bool cursor_xy_visible;
-  bool eol_changed;
 
   QHash <QString, QString> fnameswoexts;
   
-  QString new_eol;
-  QString def_eol;
+  QString eol;
+
   
   document_holder *holder;
+//  CSyntaxHighlighter *highlighter;
   CSyntaxHighlighter *highlighter;
+  
+  
   CTEAEdit *textEdit;
 
   QStringList labels;
@@ -228,7 +287,7 @@ public:
   int get_tab_idx();
   QString get_triplex();
   void update_status();
-  void update_title (bool fullname = TRUE);
+  void update_title (bool fullname = true);
 
   void update_labels();
 };
@@ -298,22 +357,24 @@ class LineNumberArea: public QWidget
 {
 public:
 
-    CTEAEdit *codeEditor;
+  CTEAEdit *codeEditor;
 
-    LineNumberArea (CTEAEdit *editor = 0) : QWidget (editor) {
-        codeEditor = editor;
-    }
+  LineNumberArea (CTEAEdit *editor = 0) : QWidget (editor)
+                 {
+                  codeEditor = editor;
+                 }
 
-    QSize sizeHint() const {
-        return QSize(codeEditor->lineNumberAreaWidth(), 0);
-    }
+  QSize sizeHint() const {
+                          return QSize(codeEditor->lineNumberAreaWidth(), 0);
+                         }
 
 protected:
-    void paintEvent(QPaintEvent *event) {
-        codeEditor->lineNumberAreaPaintEvent(event);
-    }
+
+  void paintEvent (QPaintEvent *event)
+      {
+       codeEditor->lineNumberAreaPaintEvent(event);
+      }
 
 };
 
-
 #endif
