@@ -1,5 +1,5 @@
  /**************************************************************************
- *   Copyright (C) 2007-2011 by Peter Semiletov                            *
+ *   2007-2013 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,10 +22,12 @@
 #include "utils.h"
 #include "logmemo.h"
 
+#include <QStandardItem>
 #include <QFileInfoList>
 #include <QUrl>
 #include <QMimeData>
-
+#include <QDebug>
+#include <QApplication>
 
 
 void CFMan::dir_up()
@@ -39,9 +41,10 @@ void CFMan::dir_up()
   nav (dir.path());
 
   QModelIndex index = index_from_name (oldcurdir);
-  tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select |
-                                                       QItemSelectionModel::Rows);
-  tree_view->scrollTo (index);
+
+  selectionModel()->setCurrentIndex(index, QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate);
+
+  scrollTo (index);
 }
 
 
@@ -51,14 +54,14 @@ void CFMan::nav (const QString &path)
   if (! dir.exists())
       return;
 
-  tree_view->setModel (0);
+  setModel (0);
 
-  model->removeRows (0, model->rowCount());
+  mymodel->removeRows (0, mymodel->rowCount());
   QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
                                          QDir::Files | QDir::Drives, QDir::Name |
                                          QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
 
-#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   if (path != "/")
      append_dot_entry ("..");
@@ -73,17 +76,18 @@ void CFMan::nav (const QString &path)
   foreach (QFileInfo fi, lst)
           add_entry (fi);
           
-  tree_view->setModel (model);
-  connect (tree_view->selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged (const QModelIndex &, const QModelIndex &)));
+  setModel (mymodel);
+  connect (selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged (const QModelIndex &, const QModelIndex &)));
   emit dir_changed (path);
 }
 
 
 const QModelIndex CFMan::index_from_name (const QString &name)
 {
-  QList <QStandardItem *> lst = model->findItems (name);
+  QList <QStandardItem *> lst = mymodel->findItems (name);
+
   if (lst.size() > 0)
-     return model->indexFromItem (lst[0]);
+     return mymodel->indexFromItem (lst[0]);
   else
       return QModelIndex();
 }
@@ -97,7 +101,7 @@ void CFMan::tv_activated (const QModelIndex &index)
   
   if (dpath.size() > 1)
      if (dpath.endsWith("/") || dpath.endsWith("\\"))
-      	  dpath.truncate(dpath.size() - 1);
+        dpath.truncate(dpath.size() - 1);
     
   QString full_path;
   
@@ -115,9 +119,9 @@ void CFMan::tv_activated (const QModelIndex &index)
   if (is_dir (full_path))
      {
       nav (full_path);
-      QModelIndex index = model->index (0, 0);
-      tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select |
-                                                           QItemSelectionModel::Rows);
+      QModelIndex index = mymodel->index (0, 0);
+      selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select |
+                                         QItemSelectionModel::Rows);
 
       return;
      }
@@ -131,6 +135,7 @@ void CFMan::add_entry (const QFileInfo &fi)
   QList<QStandardItem *> items;
 
   QStandardItem *item = new QStandardItem (fi.fileName());
+
   if (fi.isDir())
      {
       QFont f = item->font();
@@ -149,7 +154,7 @@ void CFMan::add_entry (const QFileInfo &fi)
   item->setFlags (Qt::ItemIsSelectable | Qt::ItemIsEnabled);
   items.append (item);
 
-  model->appendRow (items);
+  mymodel->appendRow (items);
 }
 
 
@@ -169,37 +174,47 @@ void CFMan::append_dot_entry (const QString &fname)
   item->setFlags (Qt::ItemIsSelectable | Qt::ItemIsEnabled);
   items.append (item);
 
-  model->appendRow (items);
+  mymodel->appendRow (items);
 }
 
 
-CFMan::CFMan (QObject *parent): QObject (parent)
+CFMan::CFMan (QWidget *parent): QTreeView (parent)
 {
-  model = new QStandardItemModel (0, 3, parent);
+  mymodel = new QStandardItemModel (0, 3, parent);
 
-  model->setHeaderData (0, Qt::Horizontal, QObject::tr ("Name"));
-  model->setHeaderData (1, Qt::Horizontal, QObject::tr ("Size"));
-  model->setHeaderData (2, Qt::Horizontal, QObject::tr ("Modified at"));
+  mymodel->setHeaderData (0, Qt::Horizontal, QObject::tr ("Name"));
+  mymodel->setHeaderData (1, Qt::Horizontal, QObject::tr ("Size"));
+  mymodel->setHeaderData (2, Qt::Horizontal, QObject::tr ("Modified at"));
 
-  tree_view = new CTreeView;
-  tree_view->fman = this; 
-  tree_view->setRootIsDecorated (false);
-  tree_view->setAlternatingRowColors (true);
-  tree_view->setModel (model);
+  setRootIsDecorated (false);
 
-  tree_view->setDragEnabled (true);
+  setAlternatingRowColors (true);
+  setAllColumnsShowFocus (true);
+
+  setModel (mymodel);
+
+  setDragEnabled (true);
   
-  tree_view->header()->setResizeMode (QHeaderView::ResizeToContents);
-  tree_view->header()->setStretchLastSection (false);
 
-  tree_view->setSelectionMode (QAbstractItemView::ExtendedSelection);
-  tree_view->setSelectionBehavior (QAbstractItemView::SelectRows);
+#if QT_VERSION >= 0x050000
 
-  connect (tree_view, SIGNAL(activated(const QModelIndex &)), this, SLOT(tv_activated(const QModelIndex &)));
+  header()->setSectionResizeMode (QHeaderView::ResizeToContents);
+
+#else
+
+  header()->setResizeMode (QHeaderView::ResizeToContents);
+
+#endif
+
+
+  header()->setStretchLastSection (false);
+
+  setSelectionMode (QAbstractItemView::ExtendedSelection);
+  setSelectionBehavior (QAbstractItemView::SelectRows);
+
+  connect (this, SIGNAL(activated(const QModelIndex &)), this, SLOT(tv_activated(const QModelIndex &)));
+//  connect (this, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(tv_activated(const QModelIndex &)));
 
-  evfilter = new CTvFmanKeyPressEater;
-  tree_view->installEventFilter (evfilter);
-  connect (evfilter, SIGNAL(backspacePressed()), this, SLOT(dir_up()));
 }
 
 
@@ -212,7 +227,7 @@ void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelInde
       return;
      }
 
-  QModelIndex i = tree_view->model()->index (row, 0);
+  QModelIndex i = model()->index (row, 0);
 
   QString item_string = i.data().toString();
 
@@ -223,18 +238,12 @@ void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelInde
 }
 
 
-CFMan::~CFMan()
-{
-  delete evfilter;
-}
-
-
 QString CFMan::get_sel_fname()
 {
-  if (! tree_view->selectionModel()->hasSelection())
+  if (! selectionModel()->hasSelection())
       return QString();
 
-  QModelIndex index = tree_view->selectionModel()->currentIndex();
+  QModelIndex index = selectionModel()->currentIndex();
   QString item_string = index.data().toString();
   QString full_path (dir.path());
   full_path.append ("/").append (item_string);
@@ -244,10 +253,10 @@ QString CFMan::get_sel_fname()
 
 QStringList CFMan::get_sel_fnames()
 {
-  if (! tree_view->selectionModel()->hasSelection())
+  if (! selectionModel()->hasSelection())
       return QStringList();
 
-  QModelIndexList il = tree_view->selectionModel()->QItemSelectionModel::selectedRows (0);
+  QModelIndexList il = selectionModel()->QItemSelectionModel::selectedRows (0);
   QStringList li;
 
   foreach (QModelIndex index, il)
@@ -268,41 +277,25 @@ void CFMan::refresh()
 {
   QString current;
 
-  if (tree_view->selectionModel()->hasSelection())
+  if (selectionModel()->hasSelection())
      {    
-      QModelIndex index = tree_view->selectionModel()->currentIndex();
+      QModelIndex index = selectionModel()->currentIndex();
       current = index.data().toString();
      } 
 
   nav (dir.path());
 
   QModelIndex index = index_from_name (current);
-  tree_view->selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
-  tree_view->scrollTo (index);
-}
-
-
-bool CTvFmanKeyPressEater::eventFilter (QObject *obj, QEvent *event)
-{
-  if (event->type() == QEvent::KeyPress)
-     {
-      QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
-  
-      if (keyEvent->key() == Qt::Key_Backspace)
-          emit backspacePressed();
-
-      return false;
-     }
-  else
-      return QObject::eventFilter (obj, event);
+  selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
+  scrollTo (index);
 }
 
 
 const QModelIndex CFMan::index_from_idx (int idx)
 {
-  QStandardItem *item = model->item (idx); 
+  QStandardItem *item = mymodel->item (idx);
   if (item)
-     return model->indexFromItem (item);
+     return mymodel->indexFromItem (item);
   else
       return QModelIndex();
 }
@@ -310,20 +303,20 @@ const QModelIndex CFMan::index_from_idx (int idx)
 
 int CFMan::get_sel_index()
 {
-  if (! tree_view->selectionModel()->hasSelection())
+  if (! selectionModel()->hasSelection())
      return -1;
 
-  QModelIndex index = tree_view->selectionModel()->currentIndex();
+  QModelIndex index = selectionModel()->currentIndex();
   return index.row();
 }
 
 
-void CTreeView::mouseMoveEvent (QMouseEvent *event)
+void CFMan::mouseMoveEvent (QMouseEvent *event)
 {
   if (! (event->buttons() & Qt::LeftButton)) 
      return;
 
-  QStringList l = fman->get_sel_fnames();
+  QStringList l = get_sel_fnames();
   if (l.size() < 1)
      return;
   
@@ -341,7 +334,147 @@ void CTreeView::mouseMoveEvent (QMouseEvent *event)
   if (drag->exec (Qt::CopyAction | 
                   Qt::MoveAction |
                   Qt::LinkAction) == Qt::MoveAction)
-     fman->refresh();
+     refresh();
     
   event->accept();
 }
+
+
+void CFMan::keyPressEvent (QKeyEvent *event)
+{
+  if (event->key() == Qt::Key_Insert)
+     {
+      bool sel = false;
+      QModelIndex index = selectionModel()->currentIndex();
+      int row = index.row();
+
+      if (selectionModel()->isSelected (index))
+         sel = true;
+
+      sel = ! sel;
+
+      if (sel)
+         selectionModel()->select (index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
+      else
+          selectionModel()->select (index, QItemSelectionModel::Deselect | QItemSelectionModel::Rows);
+
+
+     if (row < mymodel->rowCount() - 1)
+        {
+         row++;
+
+         QModelIndex newindex = mymodel->index (row, 0);
+
+         selectionModel()->setCurrentIndex (newindex, /*QItemSelectionModel::Select*/QItemSelectionModel::Current | QItemSelectionModel::Rows);
+         scrollTo (newindex);
+        }
+
+      event->accept();
+      return;
+     }
+
+     
+  if (event->key() == Qt::Key_Backspace)
+     {
+      dir_up();
+      event->accept();
+      return;
+     }
+
+     
+  if (event->key() == Qt::Key_Return)
+     {
+      tv_activated (currentIndex());
+      event->accept();
+
+      return;
+     }
+
+
+  if (event->key() == Qt::Key_Up)
+     {
+      if (currentIndex().row() == 0)
+         {
+          event->accept();
+          return;
+         }
+
+      selectionModel()->setCurrentIndex(indexAbove(currentIndex()), QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate );
+      event->accept();
+      return;
+     }
+     
+
+  if (event->key() == Qt::Key_Down)
+     {
+      if (currentIndex().row() == mymodel->rowCount() - 1)
+         {
+          event->accept();
+          return;
+         }
+
+      selectionModel()->setCurrentIndex( indexBelow(currentIndex()), QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate );
+      event->accept();
+      return;
+     }
+
+
+  if (event->key() == Qt::Key_PageUp)
+     {
+      QModelIndex idx = moveCursor (QAbstractItemView::MovePageUp, Qt::NoModifier);
+      selectionModel()->setCurrentIndex(idx, QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate);
+      event->accept();
+      return;
+     }
+
+
+  if (event->key() == Qt::Key_PageDown)
+     {
+      QModelIndex idx = moveCursor (QAbstractItemView::MovePageDown, Qt::NoModifier);
+      selectionModel()->setCurrentIndex(idx, QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate);
+      event->accept();
+      return;
+     }
+
+
+  if (event->key() == Qt::Key_End)
+     {
+      QModelIndex idx = mymodel->index (mymodel->rowCount() - 1, 0);
+      selectionModel()->setCurrentIndex(idx, QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate );
+      event->accept();
+      return;
+     }
+
+
+   if (event->key() == Qt::Key_Home)
+      {
+       QModelIndex idx = mymodel->index (0, 0);
+       selectionModel()->setCurrentIndex(idx, QItemSelectionModel::Rows | QItemSelectionModel::NoUpdate);
+       event->accept();
+       return;
+      }
+
+
+  QTreeView::keyPressEvent (event);
+}
+
+
+void CFMan::drawRow (QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+{
+  if (index.row() == currentIndex().row())
+ // if (index.row() == selectionModel()->currentIndex().row())
+     {
+      QStyleOptionViewItem current_option = option;
+      QTreeView::drawRow (painter, current_option, index);
+
+      QStyleOptionFocusRect o;
+      o.rect = option.rect.adjusted(1,1,-1,-1);
+      o.state |= QStyle::State_KeyboardFocusChange;
+      o.state |= QStyle::State_Item;
+
+      QApplication::style()->drawPrimitive (QStyle::PE_FrameFocusRect, &o, painter);
+     }
+ else
+    QTreeView::drawRow (painter, option, index);
+}
+
