@@ -22,7 +22,6 @@
 #ifndef FMAN_H
 #define FMAN_H
 
-//#include <QtGui>
 
 #include <QObject>
 #include <QStandardItemModel>
@@ -30,46 +29,26 @@
 #include <QHeaderView>
 #include <QDir>
 #include <QDrag>
-//#include <QMimeType>
-
+#include <QPainter>
 
 #include "tzipper.h"
 
 
-class CTreeView;
-
-
-class CTvFmanKeyPressEater: public QObject
-{
-  Q_OBJECT
-
-signals:
-
-  void backspacePressed();
-
-protected:
-
-  bool eventFilter (QObject *obj, QEvent *event);
-};
-
-
-class CFMan: public QObject
+class CFMan: public QTreeView
 {
   Q_OBJECT
 
 public:
 
-  CTvFmanKeyPressEater *evfilter;
   CZipper zipper;
   
-  QStandardItemModel *model;
-  CTreeView *tree_view;
+  QStandardItemModel *mymodel;
   QList <QFileInfo> list;
   
   QDir dir;
     
-  CFMan (QObject *parent = 0);
-  ~CFMan();
+  CFMan (QWidget *parent = 0);
+//  ~CFMan();
 
   void add_entry (const QFileInfo &fi);
   void append_dot_entry (const QString &fname);
@@ -95,18 +74,15 @@ signals:
  void file_activated (const QString &path);
  void dir_changed (const QString &path);
  void current_file_changed (const QString &path, const QString &just_name);
-};
 
 
-class CTreeView: public QTreeView
-{
-public: 
-   
-  CFMan *fman; 
-
 protected:
-  
+
   void mouseMoveEvent (QMouseEvent *event);
+  void keyPressEvent (QKeyEvent *event);
+
+  void drawRow (QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const;
 };
 
+
 #endif
