@@ -1,6 +1,13 @@
 #include "img_viewer.h"
 #include "utils.h"
 
+#include <QDebug>
+
+#include <QApplication>
+#include <QPainter>
+
+#include <QDesktopWidget>
+
 #include <QVBoxLayout>
 #include <QCryptographicHash>
 #include <QDir>
@@ -45,7 +52,9 @@ void CImgViewer::set_image_mini (const QString &fname)
 
 void CImgViewer::set_image_full (const QString &fname)
 {
-  window_full.show_image (fname);
+ // window_full.show_image (fname);
+  window_full.load_image (fname);
+ 
 }
 
 
@@ -53,7 +62,7 @@ QString CImgViewer::get_the_thumb_name (const QString &img_fname)
 {
  
 //FIXME: add OS2 tweak!
-#if !defined(Q_WS_WIN) || !defined(Q_OS_OS2)
+#if !defined(Q_OS_WIN) || !defined(Q_OS_OS2)
 
   QCryptographicHash h (QCryptographicHash::Md5); 
   
@@ -82,7 +91,7 @@ QString CImgViewer::get_the_thumb_name (const QString &img_fname)
   return QString();
 }
 
-
+/*
 CViewerWindow::CViewerWindow (QWidget *parent): QWidget (parent)
 {
   current_index = 0; 
@@ -261,7 +270,7 @@ void CViewerWindow::keyPressEvent (QKeyEvent *event)
   
   QWidget::keyPressEvent (event);
 }
-
+*/
 /*
 void CViewerWindow::show_image_from_clipboard()
 {
@@ -286,3 +295,129 @@ void CViewerWindow::show_image_from_clipboard()
   setWindowTitle (s_wnd_title);
 }
 */
+
+
+
+
+void CZORWindow::closeEvent (QCloseEvent *event)
+{
+  event->accept();
+}
+
+
+CZORWindow::CZORWindow (QWidget *parent): QWidget (parent)
+{
+  /*settings = new QSettings (QSettings::NativeFormat,
+                            QSettings::UserScope,
+                            "zor",
+                            "zor");
+
+*/
+  //fname_image = settings->value ("fname_image", "none").toString();
+
+  //if (fname_image != "none")
+    //  load_image (fname_image);
+
+
+ // setWindowTitle (tr ("ZOR. Press F1 for help"));
+  //setWindowOpacity (0.5f);
+
+//  setWindowOpacity (1.0f);
+  setMinimumSize (16, 16);
+
+  
+  //setAttribute (Qt::WA_QuitOnClose,true);
+  
+//  setWindowFlags (Qt::WindowStaysOnTopHint);
+
+
+  //QAction *quitAction = new QAction (tr ("E&xit"), this);
+  //quitAction->setShortcut (tr ("Ctrl+Q"));
+  //connect(quitAction, SIGNAL(triggered()), qApp, SLOT(quit()));
+  //addAction(quitAction);
+}
+
+CZORWindow::~CZORWindow()
+{
+  //qDebug() << "~CZORWindow()";
+
+  //settings->setValue ("fname_image", fname_image);
+  //delete settings;
+}
+
+
+void CZORWindow::paintEvent (QPaintEvent *event)
+{
+  QPainter painter (this);
+  painter.drawImage (0, 0, source_image);
+}
+
+/*
+void CZORWindow::resizeEvent(QResizeEvent *event)
+{
+  if (transform.isRotating())
+     {
+      QImage tmp = source_image.transformed (transform);
+      transformed_image = tmp.scaled (size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+     }
+  else
+  transformed_image = source_image.scaled (size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+
+  update();
+}
+
+*/
+
+void CZORWindow::load_image (const QString &fname)
+{
+  if  (! file_exists (fname))
+     return;
+
+  fname_image = fname;
+ 
+  //transform.reset();
+ 
+  source_image.load (fname);
+  //transformed_image = source_image;
+
+  //QSize new_size = source_image.size();
+  
+  bool orientation_portrait = false; 
+  bool need_to_scale = false;
+  
+  if (source_image.size().height() > source_image.size().height())
+    orientation_portrait = true;
+  
+  if (source_image.size().height() > 600 || source_image.size().width() > 800)
+     need_to_scale = true;
+  
+  if (need_to_scale)
+    {  
+     if (orientation_portrait)
+        source_image = source_image.scaled (QSize (600, 800), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+     else
+         source_image = source_image.scaled (QSize (800, 600), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+    }
+  
+  resize (source_image.size());
+    
+  QString s_wnd_title (QFileInfo (fname_image).fileName());
+  s_wnd_title.append (QString (" - %1x%2").arg (source_image.width()).arg(source_image.height()));
+  setWindowTitle (s_wnd_title);
+
+  raise();
+  activateWindow();
+}
+
+
+
+void CZORWindow::keyPressEvent (QKeyEvent * event)
+{
+  if (event->key() == Qt::Key_Escape)
+     {
+      event->accept();
+      close();
+     }
+
+  event->accept();
+}
