@@ -1,7 +1,6 @@
 #ifndef IMG_VIEWER_H
 #define IMG_VIEWER_H
 
-//#include <QtGui>
 
 #include <QObject>
 #include <QWidget>
@@ -9,6 +8,36 @@
 #include <QLabel>
 
 
+class CZORWindow : public QWidget
+{
+    Q_OBJECT
+    
+public:
+
+  QString fname_image;
+
+  QImage source_image;
+//  QImage transformed_image;
+
+//  QTransform transform;
+
+ // QSettings *settings;
+
+  CZORWindow (QWidget *parent = 0);
+  ~CZORWindow();
+
+
+  void load_image (const QString &fname);
+
+  void paintEvent (QPaintEvent *event);
+//  void resizeEvent (QResizeEvent *event);
+  void keyPressEvent ( QKeyEvent * event);
+
+  void closeEvent (QCloseEvent *event);
+
+};
+
+/*
 class CViewerWindow: public QWidget
 {  
   Q_OBJECT
@@ -23,25 +52,18 @@ public:
    int current_index;
    
    QLabel *img_full;
-
-   //QPoint orgn;
-   //QRubberBand *rubber_band;
    
    CViewerWindow (QWidget *parent = 0);
    void show_image (const QString &fname);
-//   void show_image_from_clipboard();
 
    void show_again();
    
 protected:
 
   void keyPressEvent (QKeyEvent *event);    
- // void mousePressEvent(QMouseEvent *event);
- // void mouseMoveEvent(QMouseEvent *event);
- // void mouseReleaseEvent(QMouseEvent *event);
 };
 
-
+*/
 class CImgViewer: public QObject
 {
   Q_OBJECT
@@ -49,8 +71,11 @@ class CImgViewer: public QObject
 public:
 
   QWidget window_mini; 
-  CViewerWindow window_full;
+ // CViewerWindow window_full;
 
+  CZORWindow window_full;
+
+  
   QLabel *img_mini;
 
   CImgViewer (QObject *parent = 0);
