@@ -23,8 +23,6 @@
 #define RVLN_H
 
 
-//#include <QtGui>
-
 #include "document.h"
 #include "fman.h"
 #include "calendar.h"
@@ -50,6 +48,9 @@
 #include <QCoreApplication>
 #include <QSplitter>
 #include <QTextBrowser>
+#include <QTranslator>
+#include <QProcess>
+
 
 #ifdef PRINTER_ENABLE
 
@@ -82,6 +83,27 @@ public:
 };  
 
 
+class CDarkerWindow: public QWidget
+{
+  Q_OBJECT
+
+  QSlider *slider;
+  
+public:
+
+  CDarkerWindow();
+
+protected:
+
+  void closeEvent (QCloseEvent *event);
+  
+public slots:
+ 
+ void slot_valueChanged (int value);
+};
+
+
+
 class CAboutWindow: public QWidget
 {
   Q_OBJECT
@@ -118,9 +140,6 @@ protected:
 };
 
 
-class CScriptedApp;
-
-
 class rvln: public QMainWindow
 {
   Q_OBJECT
@@ -135,13 +154,15 @@ public:
   QDate date1;
   QDate date2;
 
-  CScriptedApp *scripted_app;
+  bool portable_mode;
+
+  //CScriptedApp *scripted_app;
   CLogMemo *log;
   
   CShortcuts *shortcuts;
   CFMan *fman;
   CImgViewer *img_viewer;
-  document_holder *documents;
+//  document_holder *documents;
 
 #ifdef SPELLCHECK_ENABLE
 
@@ -178,7 +199,6 @@ public:
   QString fname_storage_file;
 
 
-  //QScriptEngine script_engine;
   QHash <QString, CMarkupPair*> hs_markup;
 
   QToolBar *tb_fman_dir;
@@ -212,7 +232,6 @@ public:
 
 #endif
 
-//  QSettings *settings;
 
   QString opt_shortcuts_string_to_find;
   QString fman_fname_to_find;
@@ -253,6 +272,10 @@ public:
   QProgressBar *pb_status;
   QLineEdit *ed_spellcheck_path;
   QLineEdit *ed_aspellcheck_path;
+  
+  QCheckBox *cb_use_qregexpsyntaxhl;
+
+  QCheckBox *cb_right_to_left;
 
   QCheckBox *cb_wordwrap;
   QCheckBox *cb_show_linenums;
@@ -260,6 +283,9 @@ public:
   QCheckBox *cb_show_margin;
   QSpinBox *spb_margin_pos;
 
+  QSpinBox *spb_fuzzy_q;
+
+
   QLineEdit *ed_label_end;
   QLineEdit *ed_label_start;
 
@@ -384,10 +410,14 @@ main window callbacks
   void fn_insert_cpp();
   void fn_insert_c();
 
+  void fn_insert_template_html5();
+
+
   bool save();
   bool saveAs();
 
   void toggle_wrap();
+  void darker();
 
   void about();
   void close_current();
@@ -446,7 +476,15 @@ main window callbacks
   void fn_filter_delete_after_sep();
 
   void fn_rm_formatting();
-  void fn_convert_quotes();
+  void fn_convert_quotes_angle();
+  void fn_convert_quotes_curly();
+  
+  void fn_convert_quotes_tex_curly();
+
+  void fn_convert_quotes_tex_angle_01();
+  void fn_convert_quotes_tex_angle_02();
+  
+  
   void fn_get_words_count();
   void fn_unitaz_abc();
   void fn_extract_words();
@@ -486,7 +524,7 @@ main window callbacks
 
 #ifdef ASPELL_ENABLE
 
-#if defined(Q_WS_WIN) || defined (Q_OS_OS2)
+#if defined(Q_OS_WIN) || defined (Q_OS_OS2)
    void pb_choose_aspell_path_clicked();
 #endif
 
@@ -517,6 +555,11 @@ main window callbacks
   void mrkup_color();
   void mrkup_text_to_html();
 
+  void search_fuzzy_mode();
+  void search_regexp_mode();
+  void search_whole_words_mode();
+
+
   void search_find();
   void search_find_next();
   void search_find_prev();
@@ -529,6 +572,9 @@ main window callbacks
   void view_toggle_fs();
   void view_stay_on_top();
 
+  void instr_font_gallery();
+  
+  
   void nav_goto_line();
   void nav_goto_right_tab();
   void nav_goto_left_tab();
@@ -660,6 +706,8 @@ main window widgets
   QMenu *menu_file_recent;
   QMenu *menu_search;
   QMenu *menu_nav;
+  QMenu *menu_instr;
+
   QMenu *menu_fm;
   QMenu *menu_fm_file_ops;
   QMenu *menu_fm_file_infos;
@@ -694,6 +742,7 @@ main window widgets
   QAction *menu_find_whole_words;
   QAction *menu_find_case;
   QAction *menu_find_regexp;
+  QAction *menu_find_fuzzy;
 
   QWidget *w_right;
   QLineEdit *ed_fman_fname;
@@ -720,7 +769,8 @@ prefs window widgets
 
 
   QLineEdit *ed_locale_override;
-
+  QLineEdit *ed_img_viewer_override;
+  
   CShortcutEntry *ent_shtcut;
   QListWidget *lv_menuitems;
 
@@ -738,6 +788,9 @@ prefs window widgets
   QCheckBox *cb_auto_img_preview;
   QCheckBox *cb_override_locale;
 
+  QCheckBox *cb_override_img_viewer;
+
+  
   QComboBox *cmb_zip_charset_in;
   QComboBox *cmb_zip_charset_out;
 
@@ -853,7 +906,7 @@ class CApplication: public QApplication
 public:
 
   CApplication (int &argc, char **argv): QApplication (argc, argv)
-               {}
+               {;}
 
   void saveState (QSessionManager &manager);
 };
