@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2007-2011 by Peter Semiletov                            *
- *   peter.semiletov@gmail.com                                             *
+ *   Copyleft 2007-2013 by Peter Semiletov                            *
+ *   tea@list.ru                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +24,7 @@
 #include "gui_utils.h"
 
 #include <QString>
+#include <QDebug>
 
 
 #include <QKeyEvent>
@@ -56,7 +57,7 @@ QString mod_to_string (Qt::KeyboardModifiers k)
 
 QString keycode_to_string (int k)
 {
- // return QKeySequence(k).toString();
+//  return QKeySequence(k).toString();
 
   QString s;
 
@@ -125,16 +126,22 @@ CShortcuts::CShortcuts (QWidget *widget)
 }
 
 
+//FIXME:
 void CShortcuts::captions_iterate()
 {
   captions.clear();
   QList <QAction *> a = w->findChildren <QAction *>();
     
   foreach (QAction *ac, a)  
+          if (ac)
           if (! ac->text().isEmpty())
-             captions.prepend (ac->text());
+             {
+              captions.prepend (ac->text());
+             // qDebug() << ac->text();
+             }
 
-  captions.sort();
+ captions.sort();
+ captions.removeDuplicates(); //nasty hack
 }
 
 
@@ -219,5 +226,7 @@ void CShortcuts::load_from_file (const QString &file_name)
 void CShortcutEntry::keyPressEvent (QKeyEvent *event)
 {
   event->accept();
-  setText (mod_to_string (event->modifiers()) + keycode_to_string (event->key()));
+  QString text = mod_to_string (event->modifiers()) + keycode_to_string (event->key());
+  setText (text);
+  qDebug() << text;
 }
