@@ -29,11 +29,11 @@
 #include <hunspell/hunspell.hxx>
 #endif
 
-//#include <QtCore>
 
 #include <QDebug>
 #include <QString>
 #include <QStringList>
+#include <QHash>
 
 
 class ASpellchecker
@@ -118,4 +118,6 @@ public:
 
 #endif
 
+
+
 #endif
