@@ -43,6 +43,39 @@ some code is taken from Scribus::util.cpp:
 
 
 
+int str_fuzzy_search (const QString &s, const QString &text_to_find, int start_pos, double q)
+{
+  int counter;
+  int result = -1;
+
+  bool jump = false;
+
+  int end_pos = s.length() - 1;
+
+  for (int i = start_pos; i < end_pos; i++)
+      {
+       if (jump)
+	      break;
+
+       counter = 0;
+       for (int j = 0; j < text_to_find.length(); j++)
+           {
+            if (s[i + j] == text_to_find[j])
+  	           counter++;
+
+            if (get_percent ((double)text_to_find.length(), (double)counter) >= q)
+	          {
+	           result = i;
+		       jump = true;
+	           break;
+	           }
+           }
+      }
+
+  return result;
+}
+
+
 QString apply_table (const QString &s, const QString &fname, bool use_regexp)
 {
   QHash<QString, QString> h = hash_load_keyval (fname);
@@ -461,14 +494,20 @@ unsigned int bin_to_decimal (const QString &s)
   return result;
 }
 
-
-QString conv_quotes (const QString &source)
+QString conv_quotes (const QString &source, const QString &c1, const QString &c2)
+//QString conv_quotes (const QString &source, bool tex_mode)
 {
-  QString c1 = "\xAB";
-  QString c2 = "\xBB";
+//  QString c1 = "\xAB";
+//  QString c2 = "\xBB";
   QString x;
   QString dest;
-
+/*
+  if (tex_mode)
+    {
+     c1 = "``";
+     c2 = "\'\'";
+    }
+  */
   bool flag = true;
   int c = source.size() - 1;
   for (int i = 0; i <= c; i++)
@@ -493,7 +532,7 @@ QString conv_quotes (const QString &source)
 
 QString strip_html (const QString &source)
 {
-  bool do_copy = false;
+  bool do_copy = true;
   QString dest;
 
   for (int i = 0; i < source.length(); i++)
