@@ -2,13 +2,50 @@
 #include "utils.h"
 #include "tzipper.h"
 
+#include <QXmlStreamReader>
+#include <QTextStream>
+#include <QDebug>
 
 
 bool CTioPlainText::load (const QString &fname)
 {
+
+ qDebug() << "EOL detection - start";
+
+  QFile feol_detector (fname);
+
+  if (! feol_detector.open (QFile::ReadOnly))
+     {
+      error_string = feol_detector.errorString();
+      return false;
+     }
+
+  QByteArray block = feol_detector.read (4096);
+
+
+  if (block.indexOf ("\r\n") != -1)
+     eol = "\r\n";
+  else
+  if (block.indexOf ('\n') != -1)
+      eol = "\n";
+  else
+      if (block.indexOf ('\r') != -1)
+          eol = "\r";
+
+   if (eol == "\n")
+     qDebug() << "LF";
+   if (eol == "\r\n")
+     qDebug() << "CRLF";
+   if (eol == "\r")
+     qDebug() << "CR";
+
+  qDebug() << "EOL detection - end";
+
+  feol_detector.close();
+
   QFile file (fname);
 
-  if (! file.open (QFile::ReadOnly | QFile::Text))
+  if (! file.open (QFile::ReadOnly/* | QFile::Text)*/))
      {
       error_string = file.errorString();
       return false;
@@ -18,6 +55,12 @@ bool CTioPlainText::load (const QString &fname)
   in.setCodec (charset.toUtf8().data());
   data = in.readAll();
 
+  if (eol == "\r\n")
+     data.replace (eol, "\n");
+  else
+  if (eol == "\r")
+     data.replace (eol, "\n");
+
   return true;
 }
 
@@ -25,7 +68,7 @@ bool CTioPlainText::load (const QString &fname)
 bool CTioPlainText::save (const QString &fname)
 {
   QFile file (fname);
-  if (! file.open (QFile::WriteOnly/* | QFile::Text*/))
+  if (! file.open (QFile::WriteOnly))
      {
       error_string = file.errorString();
       return false;
@@ -39,7 +82,7 @@ bool CTioPlainText::save (const QString &fname)
 }
 
 
-CTioHandler::CTioHandler()// (QObject *parent): QObject (parent)
+CTioHandler::CTioHandler()
 {
   default_handler = new CTioPlainText;
   list.append (default_handler);
@@ -49,7 +92,6 @@ CTioHandler::CTioHandler()// (QObject *parent): QObject (parent)
   list.append (new CTioABW);
   list.append (new CTioFB2);
   list.append (new CTioRTF);
-  list.append (new CTioSLA);
 }
 
 
@@ -108,7 +150,6 @@ CTioABW::CTioABW()
 {
   ronly = true;
   extensions.append ("abw");
-//  extensions.append ("fb2");
 }
 
 
@@ -116,285 +157,39 @@ bool CTioABW::load (const QString &fname)
 {
   QString temp = qstring_load (fname);
 
-  CXMLWalker *walker = new CABWXMLWalker;
+  data.clear();
 
-  walker->doc.setContent (temp);
-  walker->step (walker->doc.documentElement());
-  data = walker->data;
+  QXmlStreamReader xml (temp);
 
-  delete walker;
+  bool tt = false;
 
-  return true;
-}
-
-
-void CABWXMLWalker::step (QDomNode node)
-{
-  for (QDomNode n = node.firstChild(); ! n.isNull(); n = n.nextSibling())
-      {
-       QDomElement e = n.toElement();
-
-       if (e.isNull())
-          continue;
-
-       if (e.nodeName().toLower() == "p")
-          {
-           data.append (e.text());
-           data.append ("\n");
-          }
-
-        if (e.hasChildNodes())
-           step (n);
-      }
-}
-
-
-//www.codeguru.com/forum/archive/index.php/t-201658.html
-//rewritten by Peter Semiletov
-QString rtf_strip (const QString &rtf)
-{
-  int length = rtf.size();
-
-  if (length < 4)
-     return QString();
-
-  int start = 0;
-
-  start = rtf.indexOf ("\\pard");
-  if ( start < 1)
-     return QString();
-
-  QString strCopy;
-  strCopy.reserve (length);
-
-  int k = 0;
-
-  bool slash = false; //is backslash followed by the space
-  bool figure_opened = false; //is opening figure brace followed by the space
-  bool figure_closed = false; //is closing brace followed by the space
-  bool first_space = false; //else spaces are in plain text and must be included to the result
-
-  QChar ch;
-  for (int j = start; j < length; j++)
-      {
-
-       ch = rtf.at (j);
-
-       if (ch == '\\')//we are looking at the backslash
-          {
-           first_space = true;
-           slash = true;
-          }
-       else
-       if (ch == '{')
-          {
-           first_space = true;
-           figure_opened = true;
-          }
-      else
-      if (ch == '}')
-         {
-          first_space = true;
-          figure_closed = true;
-         }
-      else
-      if (ch == ' ')// &&
-          //(rtf.indexOf ("\\datafield", j - 10) + 10) != j)
-         {
-          slash = false;
-          figure_opened = false;
-          figure_closed = false;
-         }
-
-      if ( ch == '\\')
-         {
-          QChar chr = rtf.at (j + 1);
-
-          if (chr == '{') //if the text contains symbol '{'
-           {
-            slash = false;
-            figure_opened = false;
-            figure_closed = false;
-            first_space = false;
-            strCopy += '{';
-            j++;
-            k++;
-            continue;
-           }
-
-      if (chr == '}') //if the text contains symbol '}'
-         {
-          slash = false;
-          figure_opened = false;
-          figure_closed = false;
-          first_space = false;
-          strCopy += '}';
-          j++;
-          k++;
-          continue;
-         }
-
-      if (chr == '\\')//if the text contains symbol '\'
-         {
-          slash = false;
-          figure_opened = false;
-          figure_closed = false;
-          first_space = false;
-          strCopy += '\\';
-          j++;
-          continue;
-         }
-    }
-
-    if (rtf.at (j) == '\\' &&
-        rtf.at (j + 1) == 'p' &&
-        rtf.at (j + 2) == 'a' &&
-        rtf.at (j + 3) == 'r' &&
-        rtf.at (j + 4) != 'd')
-       {
-        slash = false;
-        figure_opened = false;
-        figure_closed = false;
-        first_space = false;
-        strCopy += '\n';
-        j += 4;
-        continue;
-       }
-
-    if (slash == false &&
-        figure_opened == false &&
-        figure_closed == false &&
-        ch != '\n')
+  while (! xml.atEnd())
         {
-         if (! first_space)
-            strCopy += ch;
-         else
-            first_space = false;
+         xml.readNext();
+
+         QString tag_name = xml.qualifiedName().toString().toLower();
+
+         if (xml.isStartElement())
+             if (tag_name == "p")
+                tt = true;
+
+         if (xml.isEndElement())
+            if (tag_name == "p")
+               tt = false;
+
+         if (tt && xml.isCharacters())
+            {
+             QString s = xml.text().toString();
+             if (! s.isEmpty())
+               {
+                data.append (xml.text().toString());
+                data.append("\n");
+               }
+             }
         }
-   }
 
-  return strCopy;
-}
-
-
-CTioRTF::CTioRTF()
-{
-  ronly = true;
-  extensions.append ("rtf");
-}
-
-
-bool CTioRTF::load (const QString &fname)
-{
-  QByteArray ba = file_load (fname);
-
-  QString text;
-  text.reserve (ba.size());
-
-  int i = 0;
-  int l = ba.size();
-
-  QString ansicgp;
-  int n = ba.indexOf ("ansicpg");
-  if (n != -1)
-     {
-      int m = ba.indexOf ('\\', n);
-      n += 7;
-      ansicgp = ba.mid (n, m - n);
-      //qDebug() << ansicgp;
-     }
-
-  if (ansicgp.isEmpty()) //assuming unicode
-     {
-      while (i < l)
-             if ((ba.at(i) == '\\') && (ba.at(i + 1) == 'u'))
-                {
-                 QByteArray ta = ba.mid (i, 7);
-                 ta = ta.mid (2, 4);
-                 QChar c (ta.toInt());
-                 text.append (c);
-                 i += 7 + 3;
-                }
-             else
-                 {
-                  text.append (ba.at(i));
-                  i++;
-                 }
-     }
-  else
-      {
-       ansicgp.prepend ("CP");
-       
-       QTextCodec *codec = QTextCodec::codecForName (ansicgp.toUtf8().data());
-       qDebug() << "not unicode!";
-
-       while (i < l)
-       if ((ba.at(i) == '\\') && (ba.at(i + 1) == '\''))
-          {
-           QByteArray ta = ba.mid (i, 4);
-           ta = ta.mid (2, 2);
-           QByteArray bh = ta.fromHex (ta);
-           text.append (codec->toUnicode (bh));
-           i += 4;
-          }
-       else
-           {
-            text.append (ba.at(i));
-            i++;
-           }
-       }
-
-  data = rtf_strip (text);
-
-  return true;
-}
-
-
-void CSLAXMLWalker::step (QDomNode node)
-{
-  for (QDomNode n = node.firstChild(); ! n.isNull(); n = n.nextSibling())
-      {
-       QDomElement e = n.toElement();
-
-       if (e.isNull())
-          continue;
-
-       if (e.nodeName().toLower() == "itext")
-          {
-           QString txt = e.attribute ("CH");
-
-           if (! txt.isEmpty())
-              {
-               txt = txt.replace (QChar (0x5), QChar('\n'));
-               data.append (txt);
-               data.append ("\n");
-              }
-          }
-
-        if (e.hasChildNodes())
-           step (n);
-      }
-}
-
-
-CTioSLA::CTioSLA()
-{
-  ronly = true;
-  extensions.append ("sla");
-}
-
-
-bool CTioSLA::load (const QString &fname)
-{
-  QString temp = qstring_load (fname);
-
-  CXMLWalker *walker = new CSLAXMLWalker;
-
-  walker->doc.setContent (temp);
-  walker->step (walker->doc.documentElement());
-  data = walker->data;
-
-  delete walker;
+   if (xml.hasError())
+      qDebug() << "xml parse error";
 
   return true;
 }
@@ -402,16 +197,23 @@ bool CTioSLA::load (const QString &fname)
 
 bool CTioODTSpecial::load (const QString &fname)
 {
+ qDebug() << "CTioODTSpecial::load - start";
+ 
   data.clear();
-    
-  //QString source_fname;
+
   
   CZipper zipper;
-  if (! zipper.read_as_utf8 (fname, "content.xml"))
-      return false;
   
-  QXmlStreamReader xml (zipper.string_data);
     
+  if (! zipper.read_as_utf8 (fname, "content.xml"))
+     {
+      qDebug() << "333";
+      return false;
+     }
+
+   
+  QXmlStreamReader xml (zipper.string_data);
+ 
   bool tt = false;
   while (! xml.atEnd()) 
         {
@@ -421,11 +223,6 @@ bool CTioODTSpecial::load (const QString &fname)
          
          if (xml.isStartElement()) 
             {
-             //if (tag_name == "text:p" || tag_name == "text:h")
-
-/*             if (tag_name.startsWith ("text"))
-                 tt = true;
-             else  */
              if (tag_name == "text:s")
                 {
                  QXmlStreamAttributes attrs = xml.attributes();
@@ -442,9 +239,7 @@ bool CTioODTSpecial::load (const QString &fname)
          if (xml.isEndElement()) 
             {
              if (tag_name.startsWith ("text") && tag_name != "text:span")
-
-//             if (tag_name == "text:p" || tag_name == "text:h")
-                 tt = true; 
+                tt = true;
             }
       
          
@@ -458,7 +253,9 @@ bool CTioODTSpecial::load (const QString &fname)
     
    if (xml.hasError()) 
       qDebug() << "xml parse error";
-    
+ 
+   qDebug() << "CTioODTSpecial::load - end";
+   
   return true;
 }
 
@@ -623,6 +420,288 @@ CTioFB2::CTioFB2()
 }
 
 
+bool CTioFB2::load (const QString &fname)
+{
+  data.clear();
+
+  QByteArray ba = file_load (fname);
+
+  //read encoding:
+
+  QString enc = string_between (QString (ba), "encoding=\"", "\"");
+
+  if (enc.isEmpty())
+     enc = "UTF-8";
+
+   QTextCodec *codec = QTextCodec::codecForName (enc.toLatin1().data());
+   QString temp = codec->toUnicode (ba);
+
+   QString ts = "p";
+
+   QXmlStreamReader xml (temp);
+
+   bool tt = false;
+   bool title = false;
+   bool section = false;
+
+   while (! xml.atEnd())
+         {
+          xml.readNext();
+
+          QString tag_name = xml.qualifiedName().toString().toLower();
+
+           if (xml.isStartElement())
+              {
+               if (tag_name == ts)
+                  tt = true;
+
+               if (tag_name == "title")
+                  title = true;
+
+               if (tag_name == "section")
+                  section = true;
+
+              }
+
+           if (xml.isEndElement())
+              {
+               if (tag_name == ts)
+                 tt = false;
+
+               if (tag_name == "title")
+                 {
+                  title = false;
+                  data.append("\n");
+                 }
+
+               if (tag_name == "section")
+                 {
+                  section = false;
+                  data.append("\n");
+                 }
+              }
+
+           if (tt && xml.isCharacters())
+              {
+               QString s = xml.text().toString();
+               if (! s.isEmpty())
+                 {
+                  data.append ("   ");
+                  data.append (s);
+                  data.append("\n");
+                 }
+               }
+          }
+
+  if (xml.hasError())
+    qDebug() << "xml parse error";
+
+  return true;
+}
+
+
+//www.codeguru.com/forum/archive/index.php/t-201658.html
+//rewritten by Peter Semiletov
+QString rtf_strip (const QString &rtf)
+{
+  int length = rtf.size();
+
+  if (length < 4)
+     return QString();
+
+  int start = 0;
+
+  start = rtf.indexOf ("\\pard");
+  if ( start < 1)
+     return QString();
+
+  QString strCopy;
+  strCopy.reserve (length);
+
+  int k = 0;
+
+  bool slash = false; //is backslash followed by the space
+  bool figure_opened = false; //is opening figure brace followed by the space
+  bool figure_closed = false; //is closing brace followed by the space
+  bool first_space = false; //else spaces are in plain text and must be included to the result
+
+  QChar ch;
+  for (int j = start; j < length; j++)
+      {
+
+       ch = rtf.at (j);
+
+       if (ch == '\\')//we are looking at the backslash
+          {
+           first_space = true;
+           slash = true;
+          }
+       else
+       if (ch == '{')
+          {
+           first_space = true;
+           figure_opened = true;
+          }
+      else
+      if (ch == '}')
+         {
+          first_space = true;
+          figure_closed = true;
+         }
+      else
+      if (ch == ' ')// &&
+          //(rtf.indexOf ("\\datafield", j - 10) + 10) != j)
+         {
+          slash = false;
+          figure_opened = false;
+          figure_closed = false;
+         }
+
+      if ( ch == '\\')
+         {
+          QChar chr = rtf.at (j + 1);
+
+          if (chr == '{') //if the text contains symbol '{'
+           {
+            slash = false;
+            figure_opened = false;
+            figure_closed = false;
+            first_space = false;
+            strCopy += '{';
+            j++;
+            k++;
+            continue;
+           }
+
+      if (chr == '}') //if the text contains symbol '}'
+         {
+          slash = false;
+          figure_opened = false;
+          figure_closed = false;
+          first_space = false;
+          strCopy += '}';
+          j++;
+          k++;
+          continue;
+         }
+
+      if (chr == '\\')//if the text contains symbol '\'
+         {
+          slash = false;
+          figure_opened = false;
+          figure_closed = false;
+          first_space = false;
+          strCopy += '\\';
+          j++;
+          continue;
+         }
+    }
+
+    if (rtf.at (j) == '\\' &&
+        rtf.at (j + 1) == 'p' &&
+        rtf.at (j + 2) == 'a' &&
+        rtf.at (j + 3) == 'r' &&
+        rtf.at (j + 4) != 'd')
+       {
+        slash = false;
+        figure_opened = false;
+        figure_closed = false;
+        first_space = false;
+        strCopy += '\n';
+        j += 4;
+        continue;
+       }
+
+    if (slash == false &&
+        figure_opened == false &&
+        figure_closed == false &&
+        ch != '\n')
+        {
+         if (! first_space)
+            strCopy += ch;
+         else
+            first_space = false;
+        }
+   }
+
+  return strCopy;
+}
+
+
+CTioRTF::CTioRTF()
+{
+  ronly = true;
+  extensions.append ("rtf");
+}
+
+
+bool CTioRTF::load (const QString &fname)
+{
+  QByteArray ba = file_load (fname);
+
+  QString text;
+  text.reserve (ba.size());
+
+  int i = 0;
+  int l = ba.size();
+
+  QString ansicgp;
+  int n = ba.indexOf ("ansicpg");
+  if (n != -1)
+     {
+      int m = ba.indexOf ('\\', n);
+      n += 7;
+      ansicgp = ba.mid (n, m - n);
+     }
+
+  if (ansicgp.isEmpty()) //assuming unicode
+     {
+      while (i < l)
+             if ((ba.at(i) == '\\') && (ba.at(i + 1) == 'u'))
+                {
+                 QByteArray ta = ba.mid (i, 7);
+                 ta = ta.mid (2, 4);
+                 QChar c (ta.toInt());
+                 text.append (c);
+                 i += 7 + 3;
+                }
+             else
+                 {
+                  text.append (ba.at(i));
+                  i++;
+                 }
+     }
+  else
+      {
+       ansicgp.prepend ("CP");
+
+       QTextCodec *codec = QTextCodec::codecForName (ansicgp.toUtf8().data());
+       qDebug() << "not unicode!";
+
+       while (i < l)
+       if ((ba.at(i) == '\\') && (ba.at(i + 1) == '\''))
+          {
+           QByteArray ta = ba.mid (i, 4);
+           ta = ta.mid (2, 2);
+           QByteArray bh = ta.fromHex (ta);
+           text.append (codec->toUnicode (bh));
+           i += 4;
+          }
+       else
+           {
+            text.append (ba.at(i));
+            i++;
+           }
+       }
+
+  data = rtf_strip (text);
+
+  return true;
+}
+
+
+
+
 /*
 
 <?xml version="1.0" encoding="windows-1252"?>
@@ -631,30 +710,3 @@ CTioFB2::CTioFB2()
 
 
 */
-
-bool CTioFB2::load (const QString &fname)
-{
-  QByteArray ba = file_load (fname);
-
-  //read encoding:
-
-  QString enc = string_between (QString (ba), "encoding=\"", "\"");
-  qDebug() << enc;
-
-  if (enc.isEmpty())
-      enc = "UTF-8";
-
-  QTextCodec *codec = QTextCodec::codecForName (enc.toAscii().data());
-  QString temp = codec->toUnicode (ba);
-
-  CXMLWalker *walker = new CABWXMLWalker;
-
-  walker->doc.setContent (temp);
-  walker->step (walker->doc.documentElement());
-  data = walker->data;
-
-  delete walker;
-
-  return true;
-}
-
