@@ -24,6 +24,13 @@
         <translation>Über</translation>
     </message>
 </context>
+<context>
+    <name>CDarkerWindow</name>
+    <message>
+        <source>Darker palette</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CDocument</name>
     <message>
@@ -52,6 +59,17 @@ Do you want to save your changes?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>CFontBox</name>
+    <message>
+        <source>Example string</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CImgViewer</name>
     <message>
@@ -77,7 +95,7 @@ Do you want to save your changes?</source>
     <name>CViewerWindow</name>
     <message>
         <source>preview</source>
-        <translation>Vorschau</translation>
+        <translation type="obsolete">Vorschau</translation>
     </message>
 </context>
 <context>
@@ -629,10 +647,6 @@ Do you want to overwrite?</source>
         <source>Reverse</source>
         <translation>Umkehren</translation>
     </message>
-    <message>
-        <source>Quotes to facing quotes</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Spell-checker languages</source>
         <translation>Sprachen für Rechtschreibprüfung</translation>
@@ -1431,10 +1445,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>%1 is processed and saved</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;by Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Set as storage file</source>
         <translation type="unfinished"></translation>
@@ -1499,5 +1509,73 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Leueshkanov</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Fuzzy mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fuzzy search factor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>HTML5 template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1 @ http://semiletov.org/tea&lt;/b&gt;&lt;br&gt;by Peter Semiletov (e-mail: tea@list.ru, site: semiletov.org)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>snippet %1 is not exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Old syntax hl engine (restart TEA to apply)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Instr</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use external image viewer for F2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Straight to double angle quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Straight to curly double quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Darker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX: Straight to curly double quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX: Straight to double angle quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX: Straight to double angle quotes v2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
