@@ -24,6 +24,13 @@
         <translation>A propos</translation>
     </message>
 </context>
+<context>
+    <name>CDarkerWindow</name>
+    <message>
+        <source>Darker palette</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CDocument</name>
     <message>
@@ -53,6 +60,17 @@ Do you want to save your changes?</source>
 Voulez-vous sauvegardez vos changements ?</translation>
     </message>
 </context>
+<context>
+    <name>CFontBox</name>
+    <message>
+        <source>Example string</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CImgViewer</name>
     <message>
@@ -78,11 +96,11 @@ Voulez-vous sauvegardez vos changements ?</translation>
     <name>CViewerWindow</name>
     <message>
         <source>preview</source>
-        <translation>prévisualisation</translation>
+        <translation type="obsolete">prévisualisation</translation>
     </message>
     <message>
         <source>Clipboard</source>
-        <translation>Presse-papier</translation>
+        <translation type="obsolete">Presse-papier</translation>
     </message>
 </context>
 <context>
@@ -115,11 +133,11 @@ Voulez-vous sauvegardez vos changements ?</translation>
     </message>
     <message>
         <source>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;by Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;read the Manual under the &lt;i&gt;learn&lt;/i&gt; tab!</source>
-        <translation>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;par Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;lire le manuel dans l&apos;onglet &lt;i&gt;apprendre&lt;/li&gt; !</translation>
+        <translation type="obsolete">&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;par Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;lire le manuel dans l&apos;onglet &lt;i&gt;apprendre&lt;/li&gt; !</translation>
     </message>
     <message>
         <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++)</source>
-        <translation>Tout (*);;Fichiers textes (*.txt);;Fichiers à balises (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++)</translation>
+        <translation type="obsolete">Tout (*);;Fichiers textes (*.txt);;Fichiers à balises (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++)</translation>
     </message>
     <message>
         <source>Charset</source>
@@ -646,7 +664,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Quotes to facing quotes</source>
-        <translation>Guillemets face aux guillemets</translation>
+        <translation type="obsolete">Guillemets face aux guillemets</translation>
     </message>
     <message>
         <source>Spell-checker languages</source>
@@ -999,7 +1017,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>%1 %2 kbytes&lt;br&gt;</source>
-        <translation>%1 %2 ko&lt;br&gt;</translation>
+        <translation type="obsolete">%1 %2 ko&lt;br&gt;</translation>
     </message>
     <message>
         <source>%1 is not found&lt;br&gt;</source>
@@ -1308,15 +1326,15 @@ opera=opera %s</source>
     </message>
     <message>
         <source>Capture active window</source>
-        <translation>Capturer la fenêtre active</translation>
+        <translation type="obsolete">Capturer la fenêtre active</translation>
     </message>
     <message>
         <source>Capture desktop</source>
-        <translation>Capturer le bureau</translation>
+        <translation type="obsolete">Capturer le bureau</translation>
     </message>
     <message>
         <source>Show image from clipboard</source>
-        <translation>Montrer l&apos;image à partir du presse-papier</translation>
+        <translation type="obsolete">Montrer l&apos;image à partir du presse-papier</translation>
     </message>
     <message>
         <source>Calendar</source>
@@ -1340,15 +1358,15 @@ opera=opera %s</source>
     </message>
     <message>
         <source>Days between two dates</source>
-        <translation>Jours entre deux dates</translation>
+        <translation type="obsolete">Jours entre deux dates</translation>
     </message>
     <message>
         <source>Set first date</source>
-        <translation>Mettre en place la première date</translation>
+        <translation type="obsolete">Mettre en place la première date</translation>
     </message>
     <message>
         <source>Set second date</source>
-        <translation>Mettre en place la seconde date</translation>
+        <translation type="obsolete">Mettre en place la seconde date</translation>
     </message>
     <message>
         <source>Remove day record</source>
@@ -1364,19 +1382,19 @@ opera=opera %s</source>
     </message>
     <message>
         <source>Screen capture delay, seconds</source>
-        <translation>Délai de capture d&apos;écran, secondes</translation>
+        <translation type="obsolete">Délai de capture d&apos;écran, secondes</translation>
     </message>
     <message>
         <source>Screenshot was copied to clipboard</source>
-        <translation>La capture d&apos;écran a été copiée dans le presse-papier</translation>
+        <translation type="obsolete">La capture d&apos;écran a été copiée dans le presse-papier</translation>
     </message>
     <message>
         <source>Screenshot was saved to %1</source>
-        <translation>La capture d&apos;écran a été sauvegardée dans %1</translation>
+        <translation type="obsolete">La capture d&apos;écran a été sauvegardée dans %1</translation>
     </message>
     <message>
         <source>todo</source>
-        <translation>à faire</translation>
+        <translation type="obsolete">à faire</translation>
     </message>
     <message>
         <source>Enter your daily notes here.</source>
@@ -1384,7 +1402,7 @@ opera=opera %s</source>
     </message>
     <message>
         <source>Save image from clipboard to file</source>
-        <translation>Sauvegarder l&apos;image depuis le presse-papier dans un fichier</translation>
+        <translation type="obsolete">Sauvegarder l&apos;image depuis le presse-papier dans un fichier</translation>
     </message>
     <message>
         <source>Enter your daily notes here.
@@ -1396,5 +1414,241 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
 [06:00]bonjour !
 [20:10]aller au cinéma</translation>
     </message>
+    <message>
+        <source>All (*);;Text files (*.txt);;Markup files (*.xml *.html *.htm *.);;C/C++ (*.c *.h *.cpp *.hh *.c++ *.h++ *.cxx)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Labels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set as storage file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy to storage file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start/stop capture clipboard to storage file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rename selected file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fuzzy mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++ template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moon mode on/off</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mark first date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mark last date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go to current date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Calculate moon days between dates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of days between two dates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Refresh labels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>List ZIP content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unpack ZIP to current directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add user font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Northern hemisphere</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moon phase algorithm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI tabs align</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Documents tabs align</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ZIP unpacking: file names charset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ZIP packing: file names charset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label starts with: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label ends with: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aspell directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fuzzy search factor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shortcut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is processed and saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>dates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select the file name first!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fonts (*.ttf *.otf)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 kbytes %2 &lt;br&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trigonometric 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trigonometric 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Leueshkanov</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>HTML5 template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1 @ http://semiletov.org/tea&lt;/b&gt;&lt;br&gt;by Peter Semiletov (e-mail: tea@list.ru, site: semiletov.org)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>snippet %1 is not exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open Directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Old syntax hl engine (restart TEA to apply)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Instr</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font gallery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use external image viewer for F2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Straight to double angle quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Straight to curly double quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Darker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX: Straight to curly double quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX: Straight to double angle quotes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LaTeX: Straight to double angle quotes v2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
