@@ -32,8 +32,8 @@ bool CZipper::zip_directory (const QString &archpath, const QString &dir2pack)
  
   QString zipname (archpath); //zip name has a full path ending with .zip
   zipname.append ("/").append (archname).append (".zip");
-
-  QuaZip zip (zipname, settings->value ("zip_charset_out", "UTF-8").toString());
+ 
+  QuaZip zip (zipname, settings->value ("zip_charset_out", "UTF-8").toString().trimmed());
 
   if (! zip.open (QuaZip::mdCreate))
      return false;
@@ -84,17 +84,16 @@ bool CZipper::zip_directory (const QString &archpath, const QString &dir2pack)
 
 bool CZipper::read_as_utf8 (const QString &archname, const QString &fname)
 {
-  QuaZip zip (archname, settings->value ("zip_charset_in", "UTF-8").toString());
-
+  QuaZip zip (archname, settings->value ("zip_charset_in", "UTF-8").toString().trimmed());
+    
   if (! zip.open (QuaZip::mdUnzip))
       return false;
 
-  //zip.setFileNameCodec ("IBM866");
-
   zip.setCurrentFile (fname);
+  
   if (! zip.hasCurrentFile())
       return false;
-
+  
   QuaZipFileInfo info;
   if (! zip.getCurrentFileInfo (&info))
      return false;
@@ -148,7 +147,7 @@ bool CZipper::pack_prepared()
      return false;
   
   QString zipname (archive_fullpath);
-  QuaZip zip (zipname, settings->value ("zip_charset_out", "UTF-8").toString());
+  QuaZip zip (zipname, settings->value ("zip_charset_out", "UTF-8").toString().trimmed());
 
   if (! zip.open (QuaZip::mdCreate))
       return false;
@@ -199,7 +198,7 @@ bool CZipper::pack_prepared()
 //based on the code from quazip Copyright (C) 2005-2007 Sergey A. Tachenov
 bool CZipper::unzip (const QString &archpath, const QString &destdir)
 {
-  QuaZip zip (archpath, settings->value ("zip_charset_in", "UTF-8").toString());
+  QuaZip zip (archpath, settings->value ("zip_charset_in", "UTF-8").toString().trimmed());
 
   if (! zip.open (QuaZip::mdUnzip))
       {
@@ -316,7 +315,7 @@ bool CZipper::unzip (const QString &archpath, const QString &destdir)
 
 QString CZipper::unzip_info (const QString &archpath)
 {
-  QuaZip zip (archpath, settings->value ("zip_charset_in", "UTF-8").toString());
+  QuaZip zip (archpath, settings->value ("zip_charset_in", "UTF-8").toString().trimmed());
 
   if (! zip.open (QuaZip::mdUnzip))
       {
