@@ -1,12 +1,17 @@
 #ifndef TZIPPER_H
 #define TZIPPER_H
 
-#include <QtCore>
+//#include <QtCore>
+
+#include <QObject>
+#include <QFileInfo>
+#include <QStringList>
 
 #include "quazip.h"
 #include "quazipfile.h"
 
 
+
 class CZipper: public QObject
 {
   Q_OBJECT
