@@ -239,8 +239,11 @@ QString get_insert_image (const QString &file_name, const QString &full_path, co
   QString result;
 
   if (markup_mode == "HTML")
-     result = QString ("<img src=\"%1\" border=\"0\" alt=\"\" width=\"%2\" height=\"%3\">").arg (
-                       dir.relativeFilePath (full_path)).arg (img.width()).arg (img.height());
+  //   result = QString ("<img src=\"%1\" border=\"0\" alt=\"\" width=\"%2\" height=\"%3\">").arg (
+    //                   dir.relativeFilePath (full_path)).arg (img.width()).arg (img.height());
+      result = QString ("<img src=\"%1\" alt=\"\" width=\"%2\" height=\"%3\">").arg (
+                         dir.relativeFilePath (full_path)).arg (img.width()).arg (img.height());
+
   else
   if (markup_mode == "XHTML")
      result = QString ("<img src=\"%1\" border=\"0\" alt=\"\" width=\"%2\" height=\"%3\" />").arg (
