@@ -6,7 +6,10 @@ Peter Semiletov
 #ifndef UTILS_H
 #define UTILS_H
 
-#include <QtGui>
+#include <QObject>
+#include <QHash>
+#include <QFileInfo>
+#include <QStringList>
 
 
 
